#include "config.h"


#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer librecode_yy_create_buffer
#define yy_delete_buffer librecode_yy_delete_buffer
#define yy_scan_buffer librecode_yy_scan_buffer
#define yy_scan_string librecode_yy_scan_string
#define yy_scan_bytes librecode_yy_scan_bytes
#define yy_init_buffer librecode_yy_init_buffer
#define yy_flush_buffer librecode_yy_flush_buffer
#define yy_load_buffer_state librecode_yy_load_buffer_state
#define yy_switch_to_buffer librecode_yy_switch_to_buffer
#define yypush_buffer_state librecode_yypush_buffer_state
#define yypop_buffer_state librecode_yypop_buffer_state
#define yyensure_buffer_stack librecode_yyensure_buffer_stack
#define yy_flex_debug librecode_yy_flex_debug
#define yyin librecode_yyin
#define yyleng librecode_yyleng
#define yylex librecode_yylex
#define yylineno librecode_yylineno
#define yyout librecode_yyout
#define yyrestart librecode_yyrestart
#define yytext librecode_yytext
#define yywrap librecode_yywrap
#define yyalloc librecode_yyalloc
#define yyrealloc librecode_yyrealloc
#define yyfree librecode_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define librecode_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer librecode_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define librecode_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer librecode_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define librecode_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer librecode_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define librecode_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string librecode_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define librecode_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes librecode_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define librecode_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer librecode_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define librecode_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer librecode_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define librecode_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state librecode_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define librecode_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer librecode_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define librecode_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state librecode_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define librecode_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state librecode_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define librecode_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack librecode_yyensure_buffer_stack
#endif

#ifdef yylex
#define librecode_yylex_ALREADY_DEFINED
#else
#define yylex librecode_yylex
#endif

#ifdef yyrestart
#define librecode_yyrestart_ALREADY_DEFINED
#else
#define yyrestart librecode_yyrestart
#endif

#ifdef yylex_init
#define librecode_yylex_init_ALREADY_DEFINED
#else
#define yylex_init librecode_yylex_init
#endif

#ifdef yylex_init_extra
#define librecode_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra librecode_yylex_init_extra
#endif

#ifdef yylex_destroy
#define librecode_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy librecode_yylex_destroy
#endif

#ifdef yyget_debug
#define librecode_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug librecode_yyget_debug
#endif

#ifdef yyset_debug
#define librecode_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug librecode_yyset_debug
#endif

#ifdef yyget_extra
#define librecode_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra librecode_yyget_extra
#endif

#ifdef yyset_extra
#define librecode_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra librecode_yyset_extra
#endif

#ifdef yyget_in
#define librecode_yyget_in_ALREADY_DEFINED
#else
#define yyget_in librecode_yyget_in
#endif

#ifdef yyset_in
#define librecode_yyset_in_ALREADY_DEFINED
#else
#define yyset_in librecode_yyset_in
#endif

#ifdef yyget_out
#define librecode_yyget_out_ALREADY_DEFINED
#else
#define yyget_out librecode_yyget_out
#endif

#ifdef yyset_out
#define librecode_yyset_out_ALREADY_DEFINED
#else
#define yyset_out librecode_yyset_out
#endif

#ifdef yyget_leng
#define librecode_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng librecode_yyget_leng
#endif

#ifdef yyget_text
#define librecode_yyget_text_ALREADY_DEFINED
#else
#define yyget_text librecode_yyget_text
#endif

#ifdef yyget_lineno
#define librecode_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno librecode_yyget_lineno
#endif

#ifdef yyset_lineno
#define librecode_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno librecode_yyset_lineno
#endif

#ifdef yywrap
#define librecode_yywrap_ALREADY_DEFINED
#else
#define yywrap librecode_yywrap
#endif

#ifdef yyalloc
#define librecode_yyalloc_ALREADY_DEFINED
#else
#define yyalloc librecode_yyalloc
#endif

#ifdef yyrealloc
#define librecode_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc librecode_yyrealloc
#endif

#ifdef yyfree
#define librecode_yyfree_ALREADY_DEFINED
#else
#define yyfree librecode_yyfree
#endif

#ifdef yytext
#define librecode_yytext_ALREADY_DEFINED
#else
#define yytext librecode_yytext
#endif

#ifdef yyleng
#define librecode_yyleng_ALREADY_DEFINED
#else
#define yyleng librecode_yyleng
#endif

#ifdef yyin
#define librecode_yyin_ALREADY_DEFINED
#else
#define yyin librecode_yyin
#endif

#ifdef yyout
#define librecode_yyout_ALREADY_DEFINED
#else
#define yyout librecode_yyout
#endif

#ifdef yy_flex_debug
#define librecode_yy_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug librecode_yy_flex_debug
#endif

#ifdef yylineno
#define librecode_yylineno_ALREADY_DEFINED
#else
#define yylineno librecode_yylineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define librecode_yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 451
#define YY_END_OF_BUFFER 452
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1261] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  452,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,   60,   57,   58,   59,   66,   67,   62,   63,
       64,   65,   68,   61,   69,   70,  451,  451,  451,  451,
      451,  451,  451,  451,   71,   72,   73,   74,   75,   76,
       77,   78,   79,   80,   81,   82,   83,  137,  138,  139,
      140,  141,  142,  143,  144,  145,  146,  147,  148,  149,
      150,  151,  451,  451,  451,  451,  190,  451,  451,  451,

      451,  451,  451,  451,  451,  217,  451,  451,  451,  451,
      451,  451,  308,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   89,   90,   91,   92,
       93,   84,   85,   86,   87,   88,  100,  101,  102,  103,
      104,  105,   94,   95,   96,   97,   98,   99,  111,  112,
      113,  114,  115,  106,  107,  108,  109,  110,  119,  121,
      120,  116,  118,  117,  125,  126,  122,  123,  124,  134,

      135,  136,  131,  132,  133,  128,  127,  130,  129,  152,
      153,  154,  155,  156,  157,  158,  159,  160,  161,  162,
      163,  164,  165,  166,  167,  168,  169,  170,  171,  172,
      173,  174,  175,  176,  177,  178,  179,  180,  181,  182,
      183,  184,  186,  185,  187,  189,  188,  191,  192,  193,
      194,  195,  196,  197,  198,  199,  200,  201,  202,  203,
      204,  205,  218,  235,  239,  221,  206,  207,  208,  209,
      230,  233,  225,  299,  299,  262,  220,    0,  212,    0,
      299,  299,  299,  299,  299,  299,  291,  299,  299,  299,
      213,  214,    0,  223,  309,  326,  330,  312,  300,  301,

      302,  303,  321,  324,  316,  390,  390,  353,  311,    0,
      304,    0,  390,  390,  390,  390,  390,  390,  382,  390,
      390,  305,  306,    0,  314,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  392,    0,  394,  393,
        0,    0,  404,  405,  401,    0,  414,  413,    0,    0,
      420,  419,    0,  426,  425,  391,    0,  397,  396,    0,
        0,  410,  411,  407,    0,  417,  416,    0,  423,  422,
        0,  429,  428,    1,    2,    7,   12,   16,   22,   27,
       34,   39,   43,   49,   29,   54,   56,    4,   10,   14,
       19,   25,   28,   31,   37,   41,   46,   52,   55,    8,

       35,   23,   50,    5,    3,    6,   11,    9,   15,   13,
       17,   20,   18,   21,   26,   24,   32,   38,   42,   47,
       53,   30,   36,   40,   45,   51,   33,   44,   48,  244,
      251,  255,  261,  266,    0,  273,  280,  290,  295,  297,
        0,  241,  249,  253,  258,  264,  267,    0,  270,  278,
      287,  293,  296,    0,  299,  245,  246,    0,  262,    0,
      220,    0,  242,  250,  254,  259,  265,    0,  271,  279,
      288,  294,    0,  240,  248,  252,  257,  263,    0,  269,
      277,  286,  292,    0,  274,  275,  299,  299,  299,  299,
        0,  299,  299,  299,  291,    0,  299,  268,  299,  243,

      256,  260,  272,  285,  289,    0,  335,  342,  346,  352,
      357,    0,  364,  371,  381,  386,  388,    0,  332,  340,
      344,  349,  355,  358,    0,  361,  369,  378,  384,  387,
        0,  390,  336,  337,    0,  353,    0,  311,    0,  333,
      341,  345,  350,  356,    0,  362,  370,  379,  385,    0,
      331,  339,  343,  348,  354,    0,  360,  368,  377,  383,
        0,  365,  366,  390,  390,  390,  390,    0,  390,  390,
      390,  382,    0,  390,  359,  334,  347,  351,  363,  376,
      380,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,  395,  399,
      406,  403,  415,    0,  421,  427,  398,  400,  412,  409,
      418,  424,  430,  284,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  282,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  245,    0,
      246,    0,  299,  262,  220,  283,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  281,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  274,    0,  275,
        0,  299,  247,  276,  299,  299,    0,    0,  299,  299,
      224,  291,  299,  268,    0,  299,    0,    0,    0,    0,

        0,    0,  375,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  373,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  336,    0,  337,
        0,  390,  353,  311,  374,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  372,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  365,    0,  366,    0,
      390,  338,  367,  390,  390,    0,    0,  390,  390,  315,
      382,  390,  359,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,  353,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  382,    0,
        0,    0,    0,    0,    0,    0,    0,  439,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  402,    0,  408,  284,  298,
        0,    0,  282,    0,    0,  245,  246,  283,    0,    0,
      281,    0,    0,  274,  275,  299,  299,  299,  299,  299,
      224,    0,  299,  268,  299,  375,  389,    0,    0,  373,

        0,    0,  336,  337,  374,    0,    0,  372,    0,    0,
      365,  366,  390,  390,  390,  390,  390,  315,    0,  390,
      359,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  336,    0,
        0,  337,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  365,    0,    0,
      366,    0,    0,    0,    0,    0,    0,    0,  359,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,  441,    0,    0,  445,    0,    0,
        0,    0,    0,  444,  298,    0,  284,  284,  282,  282,
      283,  283,  281,  281,  299,  232,  299,    0,    0,    0,
      224,  219,  299,  389,    0,  375,  375,  373,  373,  374,
      374,  372,  372,  390,  323,  390,    0,    0,    0,  315,
      310,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  450,    0,    0,    0,    0,
        0,    0,  447,    0,  298,  299,  299,    0,    0,    0,
      219,    0,  299,  389,  390,  390,    0,    0,    0,  310,

        0,    0,    0,    0,    0,  433,    0,    0,  449,  432,
        0,    0,    0,    0,  443,    0,    0,    0,  448,  299,
      299,  237,  236,  238,    0,    0,    0,    0,  219,  299,
      390,  390,  328,  327,  329,    0,    0,  310,    0,    0,
      440,    0,  436,    0,    0,    0,    0,  299,  299,  237,
        0,  236,    0,  238,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  299,  390,  390,  328,    0,  327,    0,
      329,    0,    0,    0,    0,    0,    0,    0,  434,    0,
        0,  442,  446,    0,    0,  216,  222,  237,  236,  238,
      210,  211,    0,    0,    0,    0,    0,    0,  299,  307,

      313,  328,  327,  329,    0,    0,    0,    0,    0,    0,
      431,  435,  437,  438,  216,    0,  222,    0,    0,    0,
      234,  228,  229,    0,  299,  307,    0,  313,    0,    0,
        0,  325,  319,  320,    0,  216,  222,  231,  227,    0,
      299,  307,  313,  322,  318,    0,    0,  299,    0,    0,
      299,    0,  226,  299,  317,  215,  215,    0,  215,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    3,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        4,    3,    5,    6,    7,    8,    9,   10,   11,    1,
        1,    1,    1,   12,   13,    1,   14,    1,   15,   16,
       17,   18,    1,    1,    1,    1,    1,   19,    1,   20,
        1,   21,   22,    1,   23,   24,   25,   26,   27,   26,
       28,   29,   30,   31,   26,   31,   26,   32,   33,   26,
       26,   26,   34,   35,   36,   26,   26,   26,   37,   26,
        1,   38,    1,   39,   40,   41,   42,   43,   44,   45,

       46,   47,   48,   49,   50,   31,   51,   52,   53,   54,
       55,   56,   26,   57,   58,   59,   60,   26,   26,   61,
       62,   26,   63,   64,   65,   66,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   67,   68,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
       69,   70,   71,   72,   73,    1,   74,    1,    1,    1,
       75,    1,    1,    1,    1,    1,   76,   77,   78,   79,
       80,   81,    1,    1,   82,    1,   83,    1,    1,    1,
       84,    1,   85,   86,   87,   88,    1,    1,    1,   89,

       90,   91,    1,    1,    1,    1,    1,   92,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   93,   94,   95,   96,   97,   98,    1,
        1,   99,  100,  101,    1,  102,    1,    1,    1,  103,
      104,  105,  106,    1,  107,    1,    1,  108,  109,    1,
      110,  111,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[112] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    1,    1,    1,
        1,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1
    } ;

static const flex_int16_t yy_base[1277] =
    {   0,
        0,    0,    0,    0,   63,    0,  106,    0,    2,   23,
       52,   54,  199,  251, 1990, 1991, 1987, 1986, 1985, 1984,
     1983, 1982, 1981, 1980, 1979, 1978, 1977, 1976, 1975, 1974,
     1973, 1972, 1971, 1970, 1969, 1968, 1967, 1966, 1965, 1964,
     1963, 1962, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991,   52,  291,  302,   54,
       51,  303,    6,   26, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991,  337,  338,  372,  349, 1991,  383,   29,   28,

     1922, 1951, 1920,  440, 1919, 1991, 1918, 1947, 1916,  501,
     1915, 1917, 1991,  545, 1943,  100, 1941,  401,  104, 1941,
      337,  415,    0, 1910,  418, 1938,  571,  559,  577,  578,
      600,  601,   55,   14, 1943, 1942,  150, 1935,  153,  570,
     1880,  634,  633, 1934,  653,  655,  653, 1932,  673,  687,
     1877,  710, 1936,  696,    4,  699, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,

     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991,  700, 1991, 1991, 1991, 1991,
      741, 1991, 1991,  327,   28,   53,   70,  772, 1991,  792,
      706,  352,  314,  133,   97,  363,  203,  208,  209,  398,
     1991, 1991,  758, 1991, 1991, 1991, 1991,  818, 1991, 1991,

     1991, 1991,  849, 1991, 1991,  602,  205,  210,  286,  880,
     1991,  900,  794,  654,  684,  459,  589,  603,  452,  703,
      687, 1991, 1991,  835, 1991,  926,   61, 1895,  292,   63,
     1885, 1897, 1884,   62,  165, 1876, 1991,    0, 1991, 1991,
      784,    0, 1925, 1991, 1991,    0, 1991, 1991,   61,    0,
     1991, 1991,    0, 1991, 1991, 1991,    0, 1991, 1991,  860,
        0, 1924, 1991, 1991,    0, 1991, 1991,    0, 1991, 1991,
        0, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,

     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1884, 1991, 1991, 1991, 1991, 1991,
      949, 1991, 1991, 1991, 1991, 1991, 1991, 1883, 1991, 1991,
     1991, 1991, 1991,  970,  455,  457,  536, 1867,  604, 1866,
      605, 1865, 1991, 1991, 1991, 1991, 1991, 1879, 1991, 1991,
     1991, 1991,  991, 1991, 1991, 1991, 1991, 1991, 1878, 1991,
     1991, 1991, 1991, 1011,  717,  722,  731,  806,  808,  786,
      840,  858,  889,  871,  753, 1862,  783,  770,  903, 1991,

     1991, 1991, 1991, 1991, 1991, 1022, 1991, 1991, 1991, 1991,
     1991, 1876, 1991, 1991, 1991, 1991, 1991, 1042, 1991, 1991,
     1991, 1991, 1991, 1991, 1875, 1991, 1991, 1991, 1991, 1991,
     1063,  790,  803,  834, 1859,  885, 1858,  891, 1857, 1991,
     1991, 1991, 1991, 1991, 1871, 1991, 1991, 1991, 1991, 1084,
     1991, 1991, 1991, 1991, 1991, 1870, 1991, 1991, 1991, 1991,
     1104,  898,  911,  914,  925,  950,  938,  931,  936,  968,
      954,  926, 1854,  959,  977, 1991, 1991, 1991, 1991, 1991,
     1991, 1115, 1135, 1166,  102,  987, 1197, 1217,  173,  980,
      995, 1860, 1152,  967, 1874, 1858, 1861, 1866, 1859, 1870,

     1861, 1860, 1859, 1853,  145,  123, 1865, 1855, 1991, 1991,
     1991, 1894, 1991,  167, 1991, 1991, 1991, 1991, 1991, 1893,
     1991, 1991, 1991, 1007, 1838, 1837, 1836, 1835, 1834, 1848,
     1832, 1831, 1830, 1829, 1828, 1032, 1827, 1826, 1825, 1824,
     1823, 1822, 1836, 1820, 1819, 1818, 1817, 1816, 1045, 1815,
     1053, 1814, 1991, 1991, 1991, 1056, 1813, 1812, 1811, 1810,
     1809, 1823, 1807, 1806, 1805, 1804, 1058, 1803, 1802, 1801,
     1800, 1799, 1813, 1797, 1796, 1795, 1794, 1065, 1793, 1070,
     1792, 1078, 1991, 1991, 1086, 1089, 1791, 1790, 1080, 1100,
     1091, 1991, 1129, 1103, 1789, 1150, 1788, 1787, 1786, 1785,

     1784, 1783, 1109, 1782, 1781, 1780, 1779, 1778, 1792, 1776,
     1775, 1774, 1773, 1772, 1153, 1771, 1770, 1769, 1768, 1767,
     1766, 1780, 1764, 1763, 1762, 1761, 1760, 1171, 1759, 1173,
     1758, 1991, 1991, 1991, 1175, 1757, 1756, 1755, 1754, 1753,
     1767, 1751, 1750, 1749, 1748, 1179, 1747, 1746, 1745, 1744,
     1743, 1757, 1741, 1740, 1739, 1738, 1183, 1737, 1185, 1736,
     1198, 1991, 1991, 1207, 1202, 1735, 1734, 1188, 1208, 1211,
     1991, 1219, 1215, 1733, 1732, 1731, 1730, 1729, 1728, 1727,
     1726, 1725, 1724, 1723, 1722, 1736, 1720, 1719, 1718, 1717,
     1716, 1256, 1715, 1714, 1713, 1712, 1711, 1710, 1724, 1708,

     1707, 1706, 1705, 1704, 1277, 1222, 1228, 1234, 1703, 1991,
     1702, 1701, 1700, 1699, 1698, 1712, 1696, 1695, 1694, 1693,
     1298, 1692, 1691, 1690, 1689, 1688, 1702, 1686, 1685, 1684,
     1683, 1318, 1238, 1259,  386,  193, 1264, 1682, 1991, 1287,
     1681, 1680, 1679, 1678, 1677, 1676, 1334, 1991, 1680, 1689,
     1696, 1682, 1676,  272, 1675, 1686,    3,  417, 1673,  422,
     1672, 1689, 1688, 1679, 1686, 1991,  498, 1991, 1242, 1272,
     1662, 1661, 1292, 1660, 1659, 1991, 1991, 1305, 1658, 1657,
     1306, 1656, 1655, 1991, 1991, 1314, 1323, 1317, 1344, 1327,
     1330, 1654, 1339, 1991, 1340, 1335, 1343, 1653, 1652, 1346,

     1651, 1650, 1991, 1991, 1359, 1649, 1648, 1360, 1647, 1646,
     1991, 1991, 1362, 1368, 1372, 1380, 1367, 1378, 1645, 1382,
     1991, 1384, 1644, 1643, 1642, 1641, 1640, 1654, 1638, 1637,
     1636, 1635, 1634, 1388, 1633, 1632, 1631, 1630, 1629, 1628,
     1642, 1626, 1625, 1624, 1623, 1622, 1389, 1621, 1991, 1393,
     1620, 1991, 1619, 1396, 1618, 1617, 1616, 1615, 1614, 1628,
     1612, 1611, 1610, 1609, 1397, 1608, 1607, 1606, 1605, 1604,
     1618, 1602, 1601, 1600, 1599, 1401, 1598, 1991, 1402, 1597,
     1991, 1596, 1595, 1594, 1593, 1592, 1405, 1591, 1991, 1590,
     1589, 1588, 1587, 1586, 1585, 1603, 1584, 1579, 1580, 1578,

     1580, 1563,  595, 1552, 1991, 1556, 1556, 1991, 1548, 1553,
     1550,  596, 1544, 1991, 1408, 1528, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1991, 1411, 1409, 1423, 1575, 1571,   18,
     1991, 1412, 1418, 1414, 1516, 1991, 1991, 1991, 1991, 1991,
     1991, 1991, 1991, 1430, 1415, 1429, 1563, 1561,  257, 1991,
     1425, 1431, 1383, 1379, 1434, 1375, 1374, 1371, 1354, 1435,
     1351, 1348, 1439, 1345, 1336, 1329, 1247, 1241,  607, 1236,
     1240,  616,  635, 1234, 1228, 1991, 1212, 1214,  738, 1212,
     1175, 1171, 1991,  753, 1991, 1443, 1447,    0, 1199, 1469,
     1452, 1114, 1477, 1991, 1480, 1466,    1, 1142,  231, 1454,

     1090, 1071, 1070, 1050, 1048, 1991, 1064, 1031, 1991, 1991,
      856, 1022, 1020, 1029, 1991, 1017, 1003, 1002, 1991, 1481,
     1484, 1488, 1498, 1500, 1034, 1028,  263, 1496, 1991, 1502,
     1506, 1513, 1515, 1516, 1517,  687, 1508, 1991, 1068,  982,
     1991,  974, 1991, 1079, 1161,  905,  901, 1523, 1524, 1525,
      880, 1527,  866, 1528,  860,  859,  843,  839,  817,  851,
      821,  816,  779, 1532, 1535, 1533, 1534,  733, 1538,  727,
     1539,  723,  724,  729,  762,  759,  757,  717, 1991, 1181,
     1262, 1991, 1991, 1526, 1547, 1545, 1546, 1991, 1991, 1991,
     1991, 1991,  710,  703,  639,  616,  612,  621, 1555, 1547,

     1551, 1991, 1991, 1991,  662,  661,  588,  521,  520,  521,
     1991, 1991, 1991, 1991, 1552,  458, 1553,  456,  454,  413,
     1991, 1991, 1991,  382, 1554, 1556,  370, 1557,  366,  352,
      331, 1991, 1991, 1991,  329, 1991, 1991, 1991, 1991,  341,
     1564, 1991, 1991, 1991, 1991,  296,  315, 1567,  307,  226,
     1565,  199, 1991, 1570, 1991, 1568, 1571,  174, 1991, 1991,
     1634, 1637, 1639, 1641,  218,  139,  102,   46,   35,   32,
        5,    2,    1,    0, 1643, 1645
    } ;

static const flex_int16_t yy_def[1277] =
    {   0,
     1261, 1261, 1261,    3, 1261,    5, 1261,    7, 1261, 1261,
     1261, 1261, 1262, 1262, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260,  114, 1260, 1260, 1260, 1260, 1260,
     1260, 1260,  114,  114, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1263, 1263, 1263, 1263, 1260, 1260, 1260,
     1263, 1263, 1263, 1263, 1263, 1263, 1263, 1263, 1263, 1263,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1264, 1264, 1264, 1264, 1260,
     1260, 1260, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
     1264, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1265, 1260, 1260,
     1260, 1266, 1260, 1260, 1260, 1267, 1260, 1260, 1260, 1268,
     1260, 1260, 1269, 1260, 1260, 1260, 1270, 1260, 1260, 1260,
     1271, 1260, 1260, 1260, 1272, 1260, 1260, 1273, 1260, 1260,
     1274, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1263, 1263, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1263, 1263, 1263, 1260, 1263, 1263,
     1260, 1263, 1263, 1263, 1260, 1260, 1263, 1263, 1263, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1264, 1264, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1264, 1264, 1264, 1260, 1264, 1264, 1260, 1264, 1264,
     1264, 1260, 1260, 1264, 1264, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1275, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1275, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1275, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1275, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1263, 1260, 1260, 1263, 1263, 1260, 1260, 1263, 1263,
     1263, 1260, 1263, 1260, 1260, 1263, 1260, 1260, 1260, 1260,

     1260, 1260, 1276, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1276, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1276, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1276, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1264, 1260, 1260, 1264, 1264, 1260, 1260, 1264, 1264, 1264,
     1260, 1264, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1275,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1263, 1263, 1263, 1263, 1263,
     1260, 1260, 1263, 1260, 1263, 1260, 1276, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1264, 1264, 1264, 1264, 1264, 1260, 1260, 1264,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1263, 1263, 1263, 1260, 1260, 1260,
     1260, 1263, 1263, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1264, 1264, 1264, 1260, 1260, 1260, 1260,
     1264, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1263, 1263, 1260, 1260, 1260,
     1260, 1260, 1263, 1260, 1264, 1264, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1263,
     1263, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1263,
     1264, 1264, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1263, 1263, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1263, 1264, 1264, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1263, 1263, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1263, 1264,

     1264, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1263, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1263, 1260, 1260, 1260, 1260, 1260, 1260, 1263, 1260, 1260,
     1263, 1260, 1260, 1263, 1260, 1263, 1260, 1260, 1260,    0,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260
    } ;

static const flex_int16_t yy_nxt[2103] =
    {   0,
     1260, 1260,  623,  622,  621,   17,  101,  619, 1005,  387,
       18,   19,  102,   20,  399, 1122, 1133, 1123, 1134,   21,
       22, 1005,   23,  103,   24, 1090,   25,  101,  206,   26,
      455,   27,   28,  102,  617,   29,   30,  616,   31,  104,
       32,   33,  105,   34,  103,   35,  402,  207,  615,   36,
      208,  259,  261,   37,   38,  459,  107,   39,  107,   40,
      104,   41,  108,  105,  108,   42,   43,  106,  403,  209,
      260,  262,  461,  109,  157,  109,  189,  195,  158,  400,
      196,  159,  653,  614,  160,  190,  191,  161,  106,  110,
      458,  110,  111,  162,  111,  192,  197,  163,  401,  455,

      198,  164,  614,  605,  613,  338,  165,  193,  194,  346,
      594,  166,  199,  595,  112,  460,  112,  113,  338,  113,
      600,  606,  346,  601,  806,   44,   45,   46,  807,   47,
       48,   49,  462,   50,   51,  455,   52,   53,  339,  493,
      340,  611,  347,   54,  348,   55,   56,   57,   58,   59,
       60,   61,   62,   63,   64,  376,   65,   66,  377,  458,
      388,   67,   68,  389,   69,  862,   70,   71,   72,   73,
       74,   75,   76,   77,   78,   79,   80,   81,   82,  863,
       83,   84,   85,   86,   87,   88,   89,   90,  404,  492,
      405,  407,   91,  408,  860,  458,  867,  861,   92,   93,

       94,   95,   96,   97,   98,  495,   99,  532,  100,  115,
      455,  455,  536,  607,  833,  406,  867,  984,  834,  608,
      609,  116,   16,  117,   16,  118,   16,   16,  119,  120,
       16,  121,   16,  120,  122,   16,  985,  123, 1259,  124,
      125,   16,  126,   16,  127,   16,   16,   16,  128,   16,
      120,   16,   16,  129,   16,   16,   16,  120,  130,   16,
       16,  115,  497, 1255, 1099,  496,  498,  535, 1136, 1137,
      458,  458,  537,  116,   16,  117,   16,  118,   16,   16,
      119,  120,   16,  121,   16,  120,  122,   16,  538,  123,
     1253,  124,  125,   16,  126,   16,  127,   16,   16,   16,

      128,   16,  120,   16,   16,  129,   16,   16,   16,  120,
      130,   16,   16,  167, 1252, 1158,  488,  168, 1159, 1001,
      169,  732, 1250,  170,  179,  200,  171,  172,  180,  455,
     1002,  181,  173,  597,  182,  201,  174,  183,  202, 1249,
      175,  598,  350,  184,  203,  176,  599,  185,  539,  456,
      177,  186,  178,  457,  455,  350,  187,  204,  489,  210,
      220,  188,  205,  211,  221,  455,  212,  222,  490,  213,
      223,  242,  214,  224,  225,  351,  491,  352,  215,  226,
      243,  244,  216,  227, 1247, 1246,  217,  228,  835,  458,
      245,  218,  229,  487,  232, 1245,  219,  230,  233,  231,

      455,  234,  246,  247,  235,  248,  342,  236,  494,  249,
      982,  343,  250,  237,  458,  251, 1244,  238,  252,  342,
      353,  239, 1006,  357,  253,  458,  240, 1008,  254,  983,
     1243,  241,  255,  353, 1242, 1006,  357,  256, 1240,  344,
     1008,  345,  257,  499,  258,  266,  267,  268,  269,  270,
      271,  272,  273,  354,  572,  355,  358,  455,  359,  649,
      458,  532,  274,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  276,  277,  275,  275,  275, 1239,  278,  279,
      280,  281,  282,  283,  275,  275,  284,  275,  275,  275,
      275,  275,  285,  286,  287,  288,  275,  289,  290,  275,

      275,  275,  291, 1014,  292,  293,  298,  299,  300,  301,
      302,  303,  304,  305,  573,  569, 1014,  458, 1238,  650,
     1237,  535, 1236,  306,  307,  307,  307,  307,  307,  307,
      307,  307,  307,  308,  309,  307,  307,  307,  651,  310,
      311,  312,  313,  314,  315,  307,  307,  316,  307,  307,
      307,  307,  307,  317,  318,  319,  320,  307,  321,  307,
      307,  307,  307,  322,  365,  323,  324,  327,  328,  329,
     1235,  330,  331,  332,  333,  378,  361,  365,  334,  335,
      390,  362,  368,  371, 1234, 1233,  327,  328,  329,  361,
      336,  532,  331,  332,  333,  368,  371,  366,  652,  367,

     1076, 1083,  334,  335,  532,  532,  459,  461,  409,  363,
      410,  364, 1106, 1076, 1083,  369,  372,  370,  373,  374,
      375, 1109,  376,  388,  533, 1106,  377,  389,  534,  378,
      390,  570,  379,  391, 1109,  380,  392,  393,  380,  379,
     1110,  381,  394,  392,  391,  382,  395,  402,  571,  383,
      396,  535, 1232, 1110,  384,  397,  532,  385,  381,  386,
      398,  387,  399,  394,  535,  535,  460,  462, 1231, 1230,
     1224,  415,  412,  416,  413,  404, 1223,  405,  382,  407,
     1222,  408,  409,  395,  410,  412,  565,  413,  415,  532,
      416,  417,  383,  422,  417,  564,  422,  396,  418,  414,

      423,  386,  419, 1221,  424,  532,  398,  420,  455,  425,
     1220,  418,  421,  423,  426,  384,  535, 1219,  427,  678,
      397,  406,  430,  403,  680,  419,  431,  424,  566,  432,
      411,  414,  433,  455,  421,  434,  426,  435,  567, 1173,
      427,  436, 1174, 1115,  575,  437,  568,  485,  420,  535,
      425,  486,  428,  429,  438,  495, 1115,  574, 1119,  439,
     1210,  440,  441,  442, 1209,  535, 1208,  443,  458, 1207,
      444, 1119,  694,  445,  682,  429,  446,  447,  448,  679,
      500, 1206,  449, 1205,  681,  455,  450, 1204,  455,  501,
      502, 1203,  532,  458,  463,  451,  532, 1202,  464,  503,

      452,  465,  453,  454,  466,  728,  610,  467,  488,  468,
      455,  504,  505,  469,  474,  496,  610,  470,  475,  610,
      506,  476, 1198, 1197,  477,  610,  471,  478, 1196,  479,
      683,  472,  695,  480,  473,  562,  730,  481,  610,  563,
      507,  686,  693,  610,  508,  458,  482,  509,  458,  684,
      510,  483,  535,  511,  484,  512,  535,  576, 1195,  513,
      455, 1141,  685,  514,  687,  729,  577,  578,  458, 1194,
      458,  519,  515,  455, 1141,  520,  579,  516,  521,  517,
      518,  522,  618,  688,  523,  524,  525,  536,  580,  581,
      526,  455,  618,  538,  527,  618,  731,  582, 1193,  689,

      757,  618,  540,  528,  653,  455,  541, 1192,  529,  542,
      530,  531,  543,  759,  618,  544,  532,  545,  691,  618,
      458,  546,  551, 1191, 1190,  547,  552,  565,  572,  553,
     1189,  583,  554,  458,  548,  555,  584,  556,  532,  549,
      532,  557,  550,  690, 1188,  558, 1185,  537,  585,  762,
     1184,  458,  532,  539,  559,  766,  532,  761,  586,  560,
      758,  532,  561,  696,  587,  458,  588,  589,  763,  590,
      532,  625,  848,  760,  767,  626,  535,  768,  627,  773,
      591,  628,  835,  592,  629,  848,  630,  535,  573,  808,
      631,  593,  637,  765,  632,  732,  638,  837,  535,  639,

      535,  770,  640,  633,  764,  641,  642,  643,  634,  869,
      635,  644,  535,  657,  849,  645,  535,  658,  772, 1181,
      659,  535,  769,  660,  646, 1143,  661, 1180,  662,  647,
      535,  648,  663,  668,  873, 1157,  664,  669, 1143,  774,
      670, 1156,  836,  671,  697,  665,  672,  649,  673,  809,
      666,  810,  674,  698,  699,  651,  675,  838,  878,  839,
      881, 1147, 1146,  700,  704,  676, 1145,  678,  705,  871,
      677,  706,  680, 1179,  707,  701,  702,  708, 1144,  709,
      455, 1142,  455,  710, 1182,  716, 1179,  711,  455,  717,
     1140,  455,  718,  891,  874,  719,  712, 1182,  720,  721,

      722,  713,  455,  714,  723,  694,  736,  650,  724, 1139,
      737,  896, 1043,  738, 1041,  652,  739,  725,  879,  740,
      882,  741,  726,  889,  727,  742,  747,  679,  886,  743,
      748,  455,  681,  749, 1039, 1037,  750,  775,  744,  751,
      458,  752,  458,  745,  887,  753,  776,  777,  458,  754,
      888,  458,  455,  892, 1138,  900,  778,  781,  755, 1135,
      890,  782,  458,  756,  783,  695, 1183,  784,  779,  780,
      785,  898,  786,  728,  841,  730,  787,  905, 1129, 1183,
      788,  908,  893,  842,  843,  757, 1211,  759,  793,  789,
      532,  458,  794,  844,  790,  795,  791,  792,  796, 1211,

      532,  797,  798,  799,  532,  845,  846,  800,  895,  532,
      532,  801,  458,  918,  847,  901, 1124,  773, 1118,  811,
      802,  532, 1117,  812,  947,  803,  813,  804,  805,  814,
      950,  916,  815,  729,  816,  731,  808,  906,  817,  822,
      976,  909,  818,  823,  869,  758,  824,  760,  913,  825,
      535,  819,  826, 1116,  827, 1114,  820, 1113,  828,  821,
      535,  979,  829,  915,  535,  914,  837, 1212,  917,  535,
      535,  830,  920,  919, 1015, 1112,  831,  774,  923,  832,
     1212,  535,  924, 1111,  948,  925,  949, 1108,  926,  987,
      951,  927,  952,  928,  873, 1107,  809,  929,  810,  935,

      977,  930,  978,  936,  871,  989,  937,  878,  881,  938,
      931,  981,  939,  940,  941,  932,  455,  933,  942,  455,
      955,  980,  943,  981,  956,  455,  838,  957,  839,  455,
      958,  944,  891,  959, 1016,  960,  945,  896,  946,  961,
      966,  455,  455,  962,  967, 1034,  455,  968,  900,  988,
      969,  989,  963,  970,  874,  971,  990,  964, 1028,  972,
     1029,  905,  908,  973,  532,  991,  992,  879,  882,  532,
      532, 1025,  974, 1027,  532,  993,  458,  975, 1026,  458,
      918, 1033,  532, 1032,  532,  458, 1052,  994,  995, 1030,
     1055,  947,  892,  978, 1047,  950, 1048,  898, 1060, 1063,

     1105,  458,  458,  976,  979, 1035,  458,  987,  901, 1105,
     1015,  455, 1104,  455, 1091, 1104, 1034,  532,  952, 1044,
      455,  906,  909, 1045,  535,  455, 1051, 1100, 1046, 1049,
      535,  532,  532, 1052,  535,  949, 1055, 1060, 1103, 1103,
      919, 1063,  535, 1102,  535,  455, 1053, 1102, 1037,  455,
     1056,  948, 1039,  949, 1091,  951, 1100,  952, 1061, 1064,
     1041, 1043, 1086,  977,  980,  978,  981,  988,  532,  989,
     1016,  458, 1087,  458, 1092, 1093, 1035,  535, 1096,  455,
      458, 1095,  532,  455, 1120,  458,  455, 1101, 1125, 1126,
     1150,  535,  535, 1053, 1121, 1037, 1056, 1061, 1039, 1041,

     1152, 1064, 1154, 1043,  455,  458, 1127, 1128,  532,  458,
     1160, 1161, 1162, 1132, 1092,  532, 1101, 1167, 1169, 1171,
     1130, 1131, 1175, 1176, 1177,  455,  455, 1150,  535, 1152,
     1154, 1213, 1149, 1163,  455,  532, 1167,  532, 1148,  458,
     1169, 1171,  535,  458, 1213, 1178,  458, 1215, 1217, 1226,
     1151, 1164, 1214, 1228, 1215, 1217,  455,  455, 1226, 1228,
     1153, 1166, 1155, 1165,  458, 1214,  455,  455,  535,  455,
     1257, 1186,  455, 1257, 1098,  535, 1097, 1168, 1170, 1172,
     1094, 1199, 1187, 1200, 1089,  458,  458, 1151, 1088, 1153,
     1155, 1201, 1085, 1084,  458,  535, 1168,  535, 1225, 1082,

     1170, 1172, 1081, 1241, 1080, 1079, 1078, 1216, 1218, 1227,
     1251, 1077, 1075, 1229, 1216, 1218,  458,  458, 1227, 1229,
     1248, 1074, 1256, 1073, 1254, 1072,  458,  458, 1071,  458,
     1258, 1070,  458, 1258,   16,   16,   16,  114,  114,  114,
      275,  275,  307,  307,  870,  870,  897,  897, 1069,  846,
      845,  844,  843,  842,  841, 1068,  839,  983,  982,  763,
      762, 1067, 1066,  831,  830,  829,  828, 1065,  826,  825,
      824,  823,  822,  820,  819,  818,  817, 1062,  815,  814,
      813,  812,  811,  810, 1059, 1058,  804,  803,  802,  801,
      800, 1057,  798,  797,  796,  795,  794,  793,  791,  790,

      789,  788,  787, 1054,  785,  784,  783,  782,  781, 1050,
     1043, 1042, 1041, 1040, 1039, 1038, 1037, 1036, 1031, 1024,
     1023, 1022, 1021, 1020, 1019, 1018, 1017, 1013, 1012, 1011,
     1010, 1009, 1007, 1004, 1003, 1000,  999,  998,  997,  996,
      581,  580,  579,  578,  577,  576,  986,  560,  559,  558,
      557,  965,  555,  554,  553,  552,  551,  549,  548,  547,
      546,  954,  544,  543,  542,  541,  540,  953,  530,  529,
      528,  527,  526,  934,  524,  523,  522,  521,  520,  519,
      517,  516,  515,  514,  513,  922,  511,  510,  509,  508,
      507,  581,  580,  579,  578,  577,  576,  921,  763,  762,

      912,  911,  560,  559,  558,  557,  910,  555,  554,  553,
      552,  551,  549,  548,  547,  546,  907,  544,  543,  542,
      541,  540,  904,  903,  530,  529,  528,  527,  526,  902,
      524,  523,  522,  521,  520,  519,  517,  516,  515,  514,
      513,  899,  511,  510,  509,  508,  507,  505,  504,  503,
      502,  501,  500,  894,  684,  683,  885,  884,  483,  482,
      481,  480,  883,  478,  477,  476,  475,  474,  472,  471,
      470,  469,  880,  467,  466,  465,  464,  463,  877,  876,
      453,  452,  451,  450,  449,  875,  447,  446,  445,  444,
      443,  442,  440,  439,  438,  437,  436,  872,  434,  433,

      432,  431,  430,  868,  866,  865,  864,  859,  858,  857,
      856,  855,  854,  853,  852,  851,  850,  840,  771,  746,
      735,  734,  733,  732,  715,  703,  692,  667,  656,  655,
      654,  653,  636,  624,  620,  612,  601,  604,  603,  602,
      596,  385,  428,  401,  393,  411,  400,  375,  374,  360,
      356,  349,  341,  337,  326,  325,  297,  296,  295,  294,
      265,  264,  263,  156,  155,  154,  153,  152,  151,  150,
      149,  148,  147,  146,  145,  144,  143,  142,  141,  140,
      139,  138,  137,  136,  135,  134,  133,  132,  131, 1260,
       15, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260
    } ;

static const flex_int16_t yy_chk[2103] =
    {   0,
        0,    0, 1274, 1273, 1272,    3,    9, 1271,  857,  155,
        3,    3,    9,    3,  155, 1088, 1097, 1088, 1097,    3,
        3,  857,    3,    9,    3, 1030,    3,   10,   63,    3,
      275,    3,    3,   10, 1270,    3,    3, 1269,    3,    9,
        3,    3,    9,    3,   10,    3,  134,   63, 1268,    3,
       64,   99,  100,    3,    3,  276,   11,    3,   12,    3,
       10,    3,   11,   10,   12,    3,    5,    9,  134,   64,
       99,  100,  277,   11,   57,   12,   60,   61,   57,  133,
       61,   57, 1030,  349,   57,   60,   60,   57,   10,   11,
      275,   12,   11,   57,   12,   60,   61,   57,  133,  285,

       61,   57,  349,  334, 1267,  116,   57,   60,   60,  119,
      327,   57,   61,  327,   11,  276,   12,   11,  116,   12,
      330,  334,  119,  330,  585,    5,    5,    5,  585,    5,
        5,    5,  277,    5,    5,  284,    5,    5,  116,  285,
      116, 1266,  119,    5,  119,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,  137,    5,    5,  139,  285,
      137,    5,    5,  139,    5,  606,    5,    5,    5,    5,
        5,    5,    5,    5,    7,    7,    7,    7,    7,  606,
        7,    7,    7,    7,    7,    7,    7,    7,  137,  284,
      137,  139,    7,  139,  605,  284,  614,  605,    7,    7,

        7,    7,    7,    7,    7,  287,    7,  307,    7,   13,
      288,  289,  308,  335,  589,  137,  614,  836,  589,  335,
     1265,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,  836,   13, 1258,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   14,  288, 1252, 1049,  287,  289,  307, 1099, 1099,
      288,  289,  308,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,  309,   14,
     1250,   14,   14,   14,   14,   14,   14,   14,   14,   14,

       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   58, 1249, 1127,  283,   58, 1127,  854,
       58, 1049, 1247,   58,   59,   62,   58,   58,   59,  274,
      854,   59,   58,  329,   59,   62,   58,   59,   62, 1246,
       58,  329,  121,   59,   62,   58,  329,   59,  309,  274,
       58,   59,   58,  274,  282,  121,   59,   62,  283,   93,
       94,   59,   62,   93,   94,  286,   93,   94,  283,   93,
       94,   96,   93,   94,   94,  121,  283,  121,   93,   94,
       96,   96,   93,   94, 1240, 1235,   93,   94,  835,  274,
       96,   93,   94,  282,   95, 1231,   93,   94,   95,   94,

      290,   95,   96,   96,   95,   98,  118,   95,  286,   98,
      835,  118,   98,   95,  282,   98, 1230,   95,   98,  118,
      122,   95,  858,  125,   98,  286,   95,  860,   98,  835,
     1229,   95,   98,  122, 1227,  858,  125,   98, 1224,  118,
      860,  118,   98,  290,   98,  104,  104,  104,  104,  104,
      104,  104,  104,  122,  319,  122,  125,  455,  125,  456,
      290,  316,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104, 1220,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,

      104,  104,  104,  867,  104,  104,  110,  110,  110,  110,
      110,  110,  110,  110,  319,  316,  867,  455, 1219,  456,
     1218,  316, 1216,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  457,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  128,  110,  110,  114,  114,  114,
     1210,  114,  114,  114,  114,  140,  127,  128,  114,  114,
      140,  127,  129,  130, 1209, 1208,  114,  114,  114,  127,
      114,  317,  114,  114,  114,  129,  130,  128,  457,  128,

     1003, 1012,  114,  114,  306,  318,  459,  461,  140,  127,
      140,  127, 1069, 1003, 1012,  129,  130,  129,  130,  131,
      131, 1072,  131,  132,  306, 1069,  131,  132,  306,  131,
      132,  317,  131,  132, 1072,  131,  132,  132,  143,  142,
     1073,  131,  132,  143,  142,  131,  132,  142,  318,  131,
      132,  317, 1207, 1073,  131,  132,  314,  131,  147,  131,
      132,  131,  132,  147,  306,  318,  459,  461, 1206, 1205,
     1198,  143,  142,  143,  142,  145, 1197,  146,  149,  145,
     1196,  146,  145,  149,  146,  145,  315,  146,  145,  321,
      146,  147,  150,  147,  145,  314,  146,  150,  145,  142,

      146,  154,  145, 1195,  146,  320,  154,  145,  281,  146,
     1194,  149,  145,  149,  146,  152,  314, 1193,  147,  485,
      152,  156,  266,  152,  486,  150,  266,  150,  315,  266,
      156,  156,  266,  487,  154,  266,  154,  266,  315, 1136,
      156,  266, 1136, 1079,  321,  266,  315,  281,  152,  321,
      152,  281,  156,  156,  266,  495, 1079,  320, 1084,  266,
     1178,  266,  266,  271, 1177,  320, 1176,  271,  281, 1175,
      271, 1084,  498,  271,  487,  152,  271,  271,  271,  485,
      293, 1174,  271, 1173,  486,  497,  271, 1172,  490,  293,
      293, 1170,  532,  487,  278,  271,  313, 1168,  278,  293,

      271,  278,  271,  271,  278,  533,  341,  278,  488,  278,
      489,  293,  293,  278,  280,  495,  341,  278,  280,  341,
      293,  280, 1163, 1162,  280,  341,  278,  280, 1161,  280,
      488,  278,  498,  280,  278,  313,  534,  280,  341,  313,
      298,  490,  497,  341,  298,  497,  280,  298,  490,  488,
      298,  280,  532,  298,  280,  298,  313,  324, 1160,  298,
      492, 1111,  489,  298,  491,  533,  324,  324,  488, 1159,
      489,  303,  298,  494, 1111,  303,  324,  298,  303,  298,
      298,  303,  360,  491,  303,  303,  303,  536,  324,  324,
      303,  493,  360,  538,  303,  360,  534,  324, 1158,  492,

      562,  360,  310,  303,  491,  499,  310, 1157,  303,  310,
      303,  303,  310,  563,  360,  310,  564,  310,  494,  360,
      492,  310,  312, 1156, 1155,  310,  312,  565,  572,  312,
     1153,  326,  312,  494,  310,  312,  326,  312,  569,  310,
      567,  312,  310,  493, 1151,  312, 1147,  536,  326,  565,
     1146,  493,  566,  538,  312,  568,  571,  564,  326,  312,
      562,  574,  312,  499,  326,  499,  326,  326,  565,  326,
      570,  441,  594,  563,  568,  441,  564,  569,  441,  575,
      326,  441,  590,  326,  441,  594,  441,  565,  572,  586,
      441,  326,  454,  567,  441,  568,  454,  591,  569,  454,

      567,  571,  454,  441,  566,  454,  454,  454,  441,  624,
      441,  454,  566,  473,  594,  454,  571,  473,  574, 1142,
      473,  574,  570,  473,  454, 1113,  473, 1140,  473,  454,
      570,  454,  473,  484,  636, 1126,  473,  484, 1113,  575,
      484, 1125,  590,  484,  506,  473,  484,  649,  484,  586,
      473,  586,  484,  506,  506,  651,  484,  591,  656,  591,
      667, 1118, 1117,  506,  518,  484, 1116,  678,  518,  624,
      484,  518,  680, 1139,  518,  506,  506,  518, 1114,  518,
      682, 1112,  689,  518, 1144,  531, 1139,  518,  685,  531,
     1108,  686,  531,  691,  636,  531,  518, 1144,  531,  531,

      531,  518,  690,  518,  531,  694,  550,  649,  531, 1107,
      550,  703, 1105,  550, 1104,  651,  550,  531,  656,  550,
      667,  550,  531,  689,  531,  550,  561,  678,  682,  550,
      561,  693,  680,  561, 1103, 1102,  561,  582,  550,  561,
      682,  561,  689,  550,  685,  561,  582,  582,  685,  561,
      686,  686,  696,  691, 1101,  715,  582,  583,  561, 1098,
      690,  583,  690,  561,  583,  694, 1145,  583,  582,  582,
      583,  703,  583,  728,  593,  730,  583,  735, 1092, 1145,
      583,  746,  693,  593,  593,  757, 1180,  759,  584,  583,
      768,  693,  584,  593,  583,  584,  583,  583,  584, 1180,

      761,  584,  584,  584,  765,  593,  593,  584,  696,  764,
      769,  584,  696,  770,  593,  715, 1089,  773, 1082,  587,
      584,  772, 1081,  587,  806,  584,  587,  584,  584,  587,
      807,  768,  587,  728,  587,  730,  808,  735,  587,  588,
      833,  746,  587,  588,  869,  757,  588,  759,  761,  588,
      768,  587,  588, 1080,  588, 1078,  587, 1077,  588,  587,
      761,  834,  588,  765,  765,  764,  837, 1181,  769,  764,
      769,  588,  772,  770,  870, 1075,  588,  773,  792,  588,
     1181,  772,  792, 1074,  806,  792,  806, 1071,  792,  840,
      807,  792,  807,  792,  873, 1070,  808,  792,  808,  805,

      833,  792,  833,  805,  869, 1068,  805,  878,  881,  805,
      792, 1067,  805,  805,  805,  792,  886,  792,  805,  888,
      821,  834,  805,  834,  821,  887,  837,  821,  837,  890,
      821,  805,  891,  821,  870,  821,  805,  896,  805,  821,
      832,  893,  895,  821,  832,  897,  889,  832,  900,  840,
      832,  840,  821,  832,  873,  832,  847,  821,  889,  832,
      889,  905,  908,  832,  913,  847,  847,  878,  881,  917,
      914,  886,  832,  888,  915,  847,  886,  832,  887,  888,
      918,  895,  916,  893,  920,  887,  922,  847,  847,  890,
      934,  947,  891, 1066,  916,  950,  916,  896,  954,  965,

     1065,  893,  895,  976,  979,  897,  889,  987,  900, 1064,
     1015, 1026, 1062, 1025, 1032, 1061, 1034, 1045, 1059,  913,
     1033,  905,  908,  914,  913, 1027,  920, 1051,  915,  917,
      914, 1046, 1044, 1052,  915, 1058, 1055, 1060, 1057, 1056,
      918, 1063,  916, 1054,  920, 1086,  922, 1053,  922, 1087,
      934,  947,  934,  947, 1091,  950, 1100,  950,  954,  965,
      954,  965, 1025,  976,  979,  976,  979,  987, 1096,  987,
     1015, 1026, 1027, 1025, 1032, 1033, 1034, 1045, 1046, 1093,
     1033, 1044, 1095, 1120, 1086, 1027, 1121, 1051, 1090, 1090,
     1122, 1046, 1044, 1052, 1087, 1052, 1055, 1060, 1055, 1060,

     1123, 1063, 1124, 1063, 1130, 1086, 1090, 1090, 1131, 1087,
     1128, 1128, 1128, 1096, 1091, 1132, 1100, 1133, 1134, 1135,
     1093, 1095, 1137, 1137, 1137, 1148, 1149, 1150, 1096, 1152,
     1154, 1184, 1121, 1128, 1164, 1166, 1167, 1165, 1120, 1093,
     1169, 1171, 1095, 1120, 1184, 1137, 1121, 1186, 1187, 1200,
     1122, 1130, 1185, 1201, 1215, 1217, 1225, 1199, 1226, 1228,
     1123, 1132, 1124, 1131, 1130, 1185, 1241, 1251, 1131, 1248,
     1256, 1148, 1254, 1257, 1048, 1132, 1047, 1133, 1134, 1135,
     1035, 1164, 1149, 1165, 1029, 1148, 1149, 1150, 1028, 1152,
     1154, 1166, 1016, 1013, 1164, 1166, 1167, 1165, 1199, 1011,

     1169, 1171, 1010, 1225, 1009, 1007, 1006, 1186, 1187, 1200,
     1248, 1004, 1002, 1201, 1215, 1217, 1225, 1199, 1226, 1228,
     1241, 1001, 1254, 1000, 1251,  999, 1241, 1251,  998, 1248,
     1256,  997, 1254, 1257, 1261, 1261, 1261, 1262, 1262, 1262,
     1263, 1263, 1264, 1264, 1275, 1275, 1276, 1276,  996,  995,
      994,  993,  992,  991,  990,  988,  986,  985,  984,  983,
      982,  980,  977,  975,  974,  973,  972,  971,  970,  969,
      968,  967,  966,  964,  963,  962,  961,  960,  959,  958,
      957,  956,  955,  953,  951,  948,  946,  945,  944,  943,
      942,  941,  940,  939,  938,  937,  936,  935,  933,  932,

      931,  930,  929,  928,  927,  926,  925,  924,  923,  919,
      910,  909,  907,  906,  902,  901,  899,  898,  892,  883,
      882,  880,  879,  875,  874,  872,  871,  865,  864,  863,
      862,  861,  859,  856,  855,  853,  852,  851,  850,  849,
      846,  845,  844,  843,  842,  841,  838,  831,  830,  829,
      828,  827,  826,  825,  824,  823,  822,  820,  819,  818,
      817,  816,  815,  814,  813,  812,  811,  809,  804,  803,
      802,  801,  800,  799,  798,  797,  796,  795,  794,  793,
      791,  790,  789,  788,  787,  786,  785,  784,  783,  782,
      781,  780,  779,  778,  777,  776,  775,  774,  767,  766,

      760,  758,  756,  755,  754,  753,  752,  751,  750,  749,
      748,  747,  745,  744,  743,  742,  741,  740,  739,  738,
      737,  736,  731,  729,  727,  726,  725,  724,  723,  722,
      721,  720,  719,  718,  717,  716,  714,  713,  712,  711,
      710,  709,  708,  707,  706,  705,  704,  702,  701,  700,
      699,  698,  697,  695,  688,  687,  681,  679,  677,  676,
      675,  674,  673,  672,  671,  670,  669,  668,  666,  665,
      664,  663,  662,  661,  660,  659,  658,  657,  652,  650,
      648,  647,  646,  645,  644,  643,  642,  641,  640,  639,
      638,  637,  635,  634,  633,  632,  631,  630,  629,  628,

      627,  626,  625,  620,  612,  608,  607,  604,  603,  602,
      601,  600,  599,  598,  597,  596,  595,  592,  573,  556,
      545,  539,  537,  535,  525,  512,  496,  479,  468,  462,
      460,  458,  448,  435,  362,  343,  336,  333,  332,  331,
      328,  153,  151,  148,  144,  141,  138,  136,  135,  126,
      124,  120,  117,  115,  112,  111,  109,  108,  107,  105,
      103,  102,  101,   42,   41,   40,   39,   38,   37,   36,
       35,   34,   33,   32,   31,   30,   29,   28,   27,   26,
       25,   24,   23,   22,   21,   20,   19,   18,   17,   15,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,
     1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260, 1260,

     1260, 1260
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
/* This file is generated automatically by `mergelex.py'.  */
#include "common.h"
static RECODE_CONST_REQUEST request;
static RECODE_SUBTASK subtask;

#define YY_INPUT(buf, result, max_size)   {     int c = recode_get_byte (subtask);     result = (c == EOF) ? YY_NULL : (buf[0] = c, 1);   }

void texte_latin1_diaeresis (void);


#define INITIAL 0
#define ascii_latin1 1
#define iso5426_latin1 2
#define ansel_latin1 3
#define latex_latin1 4
#define bibtex_latin1 5
#define texte_latin1 6

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{


	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1261 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1991 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ascii_latin1):
case YY_STATE_EOF(iso5426_latin1):
case YY_STATE_EOF(ansel_latin1):
case YY_STATE_EOF(latex_latin1):
case YY_STATE_EOF(bibtex_latin1):
case YY_STATE_EOF(texte_latin1):
{ return 1; }
	YY_BREAK

case 1:
YY_RULE_SETUP
{ recode_put_byte (171, subtask); }
	YY_BREAK
case 2:
YY_RULE_SETUP
{ recode_put_byte (187, subtask); }
	YY_BREAK
case 3:
YY_RULE_SETUP
{ recode_put_byte (192, subtask); }
	YY_BREAK
case 4:
YY_RULE_SETUP
{ recode_put_byte (193, subtask); }
	YY_BREAK
case 5:
YY_RULE_SETUP
{ recode_put_byte (194, subtask); }
	YY_BREAK
case 6:
YY_RULE_SETUP
{ recode_put_byte (195, subtask); }
	YY_BREAK
case 7:
YY_RULE_SETUP
{ recode_put_byte (196, subtask); }
	YY_BREAK
case 8:
YY_RULE_SETUP
{ recode_put_byte (199, subtask); }
	YY_BREAK
case 9:
YY_RULE_SETUP
{ recode_put_byte (200, subtask); }
	YY_BREAK
case 10:
YY_RULE_SETUP
{ recode_put_byte (201, subtask); }
	YY_BREAK
case 11:
YY_RULE_SETUP
{ recode_put_byte (202, subtask); }
	YY_BREAK
case 12:
YY_RULE_SETUP
{ recode_put_byte (203, subtask); }
	YY_BREAK
case 13:
YY_RULE_SETUP
{ recode_put_byte (204, subtask); }
	YY_BREAK
case 14:
YY_RULE_SETUP
{ recode_put_byte (205, subtask); }
	YY_BREAK
case 15:
YY_RULE_SETUP
{ recode_put_byte (206, subtask); }
	YY_BREAK
case 16:
YY_RULE_SETUP
{ recode_put_byte (207, subtask); }
	YY_BREAK
case 17:
YY_RULE_SETUP
{ recode_put_byte (209, subtask); }
	YY_BREAK
case 18:
YY_RULE_SETUP
{ recode_put_byte (210, subtask); }
	YY_BREAK
case 19:
YY_RULE_SETUP
{ recode_put_byte (211, subtask); }
	YY_BREAK
case 20:
YY_RULE_SETUP
{ recode_put_byte (212, subtask); }
	YY_BREAK
case 21:
YY_RULE_SETUP
{ recode_put_byte (213, subtask); }
	YY_BREAK
case 22:
YY_RULE_SETUP
{ recode_put_byte (214, subtask); }
	YY_BREAK
case 23:
YY_RULE_SETUP
{ recode_put_byte (216, subtask); }
	YY_BREAK
case 24:
YY_RULE_SETUP
{ recode_put_byte (217, subtask); }
	YY_BREAK
case 25:
YY_RULE_SETUP
{ recode_put_byte (218, subtask); }
	YY_BREAK
case 26:
YY_RULE_SETUP
{ recode_put_byte (219, subtask); }
	YY_BREAK
case 27:
YY_RULE_SETUP
{ recode_put_byte (220, subtask); }
	YY_BREAK
case 28:
YY_RULE_SETUP
{ recode_put_byte (221, subtask); }
	YY_BREAK
case 29:
YY_RULE_SETUP
{ recode_put_byte (223, subtask); }
	YY_BREAK
case 30:
YY_RULE_SETUP
{ recode_put_byte (224, subtask); }
	YY_BREAK
case 31:
YY_RULE_SETUP
{ recode_put_byte (225, subtask); }
	YY_BREAK
case 32:
YY_RULE_SETUP
{ recode_put_byte (226, subtask); }
	YY_BREAK
case 33:
YY_RULE_SETUP
{ recode_put_byte (227, subtask); }
	YY_BREAK
case 34:
YY_RULE_SETUP
{ recode_put_byte (228, subtask); }
	YY_BREAK
case 35:
YY_RULE_SETUP
{ recode_put_byte (231, subtask); }
	YY_BREAK
case 36:
YY_RULE_SETUP
{ recode_put_byte (232, subtask); }
	YY_BREAK
case 37:
YY_RULE_SETUP
{ recode_put_byte (233, subtask); }
	YY_BREAK
case 38:
YY_RULE_SETUP
{ recode_put_byte (234, subtask); }
	YY_BREAK
case 39:
YY_RULE_SETUP
{ recode_put_byte (235, subtask); }
	YY_BREAK
case 40:
YY_RULE_SETUP
{ recode_put_byte (236, subtask); }
	YY_BREAK
case 41:
YY_RULE_SETUP
{ recode_put_byte (237, subtask); }
	YY_BREAK
case 42:
YY_RULE_SETUP
{ recode_put_byte (238, subtask); }
	YY_BREAK
case 43:
YY_RULE_SETUP
{ recode_put_byte (239, subtask); }
	YY_BREAK
case 44:
YY_RULE_SETUP
{ recode_put_byte (241, subtask); }
	YY_BREAK
case 45:
YY_RULE_SETUP
{ recode_put_byte (242, subtask); }
	YY_BREAK
case 46:
YY_RULE_SETUP
{ recode_put_byte (243, subtask); }
	YY_BREAK
case 47:
YY_RULE_SETUP
{ recode_put_byte (244, subtask); }
	YY_BREAK
case 48:
YY_RULE_SETUP
{ recode_put_byte (245, subtask); }
	YY_BREAK
case 49:
YY_RULE_SETUP
{ recode_put_byte (246, subtask); }
	YY_BREAK
case 50:
YY_RULE_SETUP
{ recode_put_byte (248, subtask); }
	YY_BREAK
case 51:
YY_RULE_SETUP
{ recode_put_byte (249, subtask); }
	YY_BREAK
case 52:
YY_RULE_SETUP
{ recode_put_byte (250, subtask); }
	YY_BREAK
case 53:
YY_RULE_SETUP
{ recode_put_byte (251, subtask); }
	YY_BREAK
case 54:
YY_RULE_SETUP
{ recode_put_byte (252, subtask); }
	YY_BREAK
case 55:
YY_RULE_SETUP
{ recode_put_byte (253, subtask); }
	YY_BREAK
case 56:
YY_RULE_SETUP
{ recode_put_byte (255, subtask); }
	YY_BREAK


case 57:
YY_RULE_SETUP
{ recode_put_byte (123, subtask); }
	YY_BREAK
case 58:
YY_RULE_SETUP
{ recode_put_byte (124, subtask); }
	YY_BREAK
case 59:
YY_RULE_SETUP
{ recode_put_byte (125, subtask); }
	YY_BREAK
case 60:
YY_RULE_SETUP
{ recode_put_byte (36, subtask); }
	YY_BREAK
case 61:
YY_RULE_SETUP
{ recode_put_byte (158, subtask); } 
	YY_BREAK
case 62:
YY_RULE_SETUP
{ recode_put_byte (161, subtask); }
	YY_BREAK
case 63:
YY_RULE_SETUP
{ recode_put_byte (163, subtask); }
	YY_BREAK
case 64:
YY_RULE_SETUP
{ recode_put_byte (36, subtask);  }
	YY_BREAK
case 65:
YY_RULE_SETUP
{ recode_put_byte (167, subtask); } 
	YY_BREAK
case 66:
YY_RULE_SETUP
{ recode_put_byte (172, subtask); }
	YY_BREAK
case 67:
YY_RULE_SETUP
{ recode_put_byte (172, subtask); }
	YY_BREAK
case 68:
YY_RULE_SETUP
{ recode_put_byte (171, subtask); } 
	YY_BREAK
case 69:
YY_RULE_SETUP
{ recode_put_byte (187, subtask); }
	YY_BREAK
case 70:
YY_RULE_SETUP
{ recode_put_byte (191, subtask); } 
	YY_BREAK
case 71:
YY_RULE_SETUP
{ recode_put_byte (198, subtask); }
	YY_BREAK
case 72:
YY_RULE_SETUP
{ recode_put_byte (208, subtask); }
	YY_BREAK
case 73:
YY_RULE_SETUP
{ recode_put_byte (76, subtask); }
	YY_BREAK
case 74:
YY_RULE_SETUP
{ recode_put_byte (216, subtask); }
	YY_BREAK
case 75:
YY_RULE_SETUP
{ recode_put_byte (254, subtask); }
	YY_BREAK
case 76:
YY_RULE_SETUP
{ recode_put_byte (230, subtask); }
	YY_BREAK
case 77:
YY_RULE_SETUP
{ recode_put_byte (100, subtask); }
	YY_BREAK
case 78:
YY_RULE_SETUP
{ recode_put_byte (240, subtask); }
	YY_BREAK
case 79:
YY_RULE_SETUP
{ recode_put_byte (134, subtask); }
	YY_BREAK
case 80:
YY_RULE_SETUP
{ recode_put_byte (108, subtask); }
	YY_BREAK
case 81:
YY_RULE_SETUP
{ recode_put_byte (248, subtask); }
	YY_BREAK
case 82:
YY_RULE_SETUP
{ recode_put_byte (223, subtask); }
	YY_BREAK
case 83:
YY_RULE_SETUP
{ recode_put_byte (222, subtask); } 
	YY_BREAK
case 84:
YY_RULE_SETUP
{ recode_put_byte (224, subtask); } 
	YY_BREAK
case 85:
YY_RULE_SETUP
{ recode_put_byte (232, subtask); } 
	YY_BREAK
case 86:
YY_RULE_SETUP
{ recode_put_byte (236, subtask); } 
	YY_BREAK
case 87:
YY_RULE_SETUP
{ recode_put_byte (242, subtask); } 
	YY_BREAK
case 88:
YY_RULE_SETUP
{ recode_put_byte (249, subtask); } 
	YY_BREAK
case 89:
YY_RULE_SETUP
{ recode_put_byte (192, subtask); } 
	YY_BREAK
case 90:
YY_RULE_SETUP
{ recode_put_byte (200, subtask); } 
	YY_BREAK
case 91:
YY_RULE_SETUP
{ recode_put_byte (204, subtask); } 
	YY_BREAK
case 92:
YY_RULE_SETUP
{ recode_put_byte (210, subtask); } 
	YY_BREAK
case 93:
YY_RULE_SETUP
{ recode_put_byte (217, subtask); } 
	YY_BREAK
case 94:
YY_RULE_SETUP
{ recode_put_byte (225, subtask); } 
	YY_BREAK
case 95:
YY_RULE_SETUP
{ recode_put_byte (233, subtask); } 
	YY_BREAK
case 96:
YY_RULE_SETUP
{ recode_put_byte (237, subtask); } 
	YY_BREAK
case 97:
YY_RULE_SETUP
{ recode_put_byte (243, subtask); } 
	YY_BREAK
case 98:
YY_RULE_SETUP
{ recode_put_byte (250, subtask); } 
	YY_BREAK
case 99:
YY_RULE_SETUP
{ recode_put_byte (253, subtask); } 
	YY_BREAK
case 100:
YY_RULE_SETUP
{ recode_put_byte (193, subtask); } 
	YY_BREAK
case 101:
YY_RULE_SETUP
{ recode_put_byte (201, subtask); } 
	YY_BREAK
case 102:
YY_RULE_SETUP
{ recode_put_byte (205, subtask); } 
	YY_BREAK
case 103:
YY_RULE_SETUP
{ recode_put_byte (211, subtask); } 
	YY_BREAK
case 104:
YY_RULE_SETUP
{ recode_put_byte (218, subtask); } 
	YY_BREAK
case 105:
YY_RULE_SETUP
{ recode_put_byte (221, subtask); } 
	YY_BREAK
case 106:
YY_RULE_SETUP
{ recode_put_byte (226, subtask); } 
	YY_BREAK
case 107:
YY_RULE_SETUP
{ recode_put_byte (234, subtask); } 
	YY_BREAK
case 108:
YY_RULE_SETUP
{ recode_put_byte (238, subtask); } 
	YY_BREAK
case 109:
YY_RULE_SETUP
{ recode_put_byte (244, subtask); } 
	YY_BREAK
case 110:
YY_RULE_SETUP
{ recode_put_byte (251, subtask); } 
	YY_BREAK
case 111:
YY_RULE_SETUP
{ recode_put_byte (194, subtask); } 
	YY_BREAK
case 112:
YY_RULE_SETUP
{ recode_put_byte (202, subtask); } 
	YY_BREAK
case 113:
YY_RULE_SETUP
{ recode_put_byte (206, subtask); } 
	YY_BREAK
case 114:
YY_RULE_SETUP
{ recode_put_byte (212, subtask); } 
	YY_BREAK
case 115:
YY_RULE_SETUP
{ recode_put_byte (219, subtask); } 
	YY_BREAK
case 116:
YY_RULE_SETUP
{ recode_put_byte (227, subtask); } 
	YY_BREAK
case 117:
YY_RULE_SETUP
{ recode_put_byte (245, subtask); } 
	YY_BREAK
case 118:
YY_RULE_SETUP
{ recode_put_byte (241, subtask); } 
	YY_BREAK
case 119:
YY_RULE_SETUP
{ recode_put_byte (195, subtask); } 
	YY_BREAK
case 120:
YY_RULE_SETUP
{ recode_put_byte (213, subtask); } 
	YY_BREAK
case 121:
YY_RULE_SETUP
{ recode_put_byte (209, subtask); } 
	YY_BREAK
case 122:
YY_RULE_SETUP
{ recode_put_byte (235, subtask); } 
	YY_BREAK
case 123:
YY_RULE_SETUP
{ recode_put_byte (239, subtask); } 
	YY_BREAK
case 124:
YY_RULE_SETUP
{ recode_put_byte (255, subtask); } 
	YY_BREAK
case 125:
YY_RULE_SETUP
{ recode_put_byte (203, subtask); } 
	YY_BREAK
case 126:
YY_RULE_SETUP
{ recode_put_byte (207, subtask); } 
	YY_BREAK
case 127:
YY_RULE_SETUP
{ recode_put_byte (229, subtask); } 
	YY_BREAK
case 128:
YY_RULE_SETUP
{ recode_put_byte (197, subtask); } 
	YY_BREAK
case 129:
YY_RULE_SETUP
{ recode_put_byte (231, subtask); } 
	YY_BREAK
case 130:
YY_RULE_SETUP
{ recode_put_byte (199, subtask); } 
	YY_BREAK
case 131:
YY_RULE_SETUP
{ recode_put_byte (228, subtask); } 
	YY_BREAK
case 132:
YY_RULE_SETUP
{ recode_put_byte (246, subtask); } 
	YY_BREAK
case 133:
YY_RULE_SETUP
{ recode_put_byte (252, subtask); } 
	YY_BREAK
case 134:
YY_RULE_SETUP
{ recode_put_byte (196, subtask); } 
	YY_BREAK
case 135:
YY_RULE_SETUP
{ recode_put_byte (214, subtask); } 
	YY_BREAK
case 136:
YY_RULE_SETUP
{ recode_put_byte (220, subtask); }   
	YY_BREAK


case 137:
YY_RULE_SETUP
{ recode_put_byte (76, subtask); }
	YY_BREAK
case 138:
YY_RULE_SETUP
{ recode_put_byte (216, subtask); }
	YY_BREAK
case 139:
YY_RULE_SETUP
{ recode_put_byte (208, subtask); }
	YY_BREAK
case 140:
YY_RULE_SETUP
{ recode_put_byte (222, subtask); }
	YY_BREAK
case 141:
YY_RULE_SETUP
{ recode_put_byte (198, subtask); }
	YY_BREAK
case 142:
YY_RULE_SETUP
{ recode_put_byte (177, subtask); }
	YY_BREAK
case 143:
YY_RULE_SETUP
{ recode_put_byte (108, subtask); }
	YY_BREAK
case 144:
YY_RULE_SETUP
{ recode_put_byte (248, subtask); }
	YY_BREAK
case 145:
YY_RULE_SETUP
{ recode_put_byte (240, subtask); }
	YY_BREAK
case 146:
YY_RULE_SETUP
{ recode_put_byte (254, subtask); }
	YY_BREAK
case 147:
YY_RULE_SETUP
{ recode_put_byte (230, subtask); }
	YY_BREAK
case 148:
YY_RULE_SETUP
{ recode_put_byte (111, subtask); }
	YY_BREAK
case 149:
YY_RULE_SETUP
{ recode_put_byte (163, subtask); }
	YY_BREAK
case 150:
YY_RULE_SETUP
{ recode_put_byte (169, subtask); }
	YY_BREAK
case 151:
YY_RULE_SETUP
{ recode_put_byte (191, subtask); }
	YY_BREAK
case 152:
YY_RULE_SETUP
{ recode_put_byte (192, subtask); }
	YY_BREAK
case 153:
YY_RULE_SETUP
{ recode_put_byte (200, subtask); }
	YY_BREAK
case 154:
YY_RULE_SETUP
{ recode_put_byte (204, subtask); }
	YY_BREAK
case 155:
YY_RULE_SETUP
{ recode_put_byte (210, subtask); }
	YY_BREAK
case 156:
YY_RULE_SETUP
{ recode_put_byte (217, subtask); }
	YY_BREAK
case 157:
YY_RULE_SETUP
{ recode_put_byte (224, subtask); }
	YY_BREAK
case 158:
YY_RULE_SETUP
{ recode_put_byte (232, subtask); }
	YY_BREAK
case 159:
YY_RULE_SETUP
{ recode_put_byte (236, subtask); }
	YY_BREAK
case 160:
YY_RULE_SETUP
{ recode_put_byte (242, subtask); }
	YY_BREAK
case 161:
YY_RULE_SETUP
{ recode_put_byte (249, subtask); }
	YY_BREAK
case 162:
YY_RULE_SETUP
{ recode_put_byte (193, subtask); }
	YY_BREAK
case 163:
YY_RULE_SETUP
{ recode_put_byte (201, subtask); }
	YY_BREAK
case 164:
YY_RULE_SETUP
{ recode_put_byte (205, subtask); }
	YY_BREAK
case 165:
YY_RULE_SETUP
{ recode_put_byte (211, subtask); }
	YY_BREAK
case 166:
YY_RULE_SETUP
{ recode_put_byte (218, subtask); }
	YY_BREAK
case 167:
YY_RULE_SETUP
{ recode_put_byte (221, subtask); }
	YY_BREAK
case 168:
YY_RULE_SETUP
{ recode_put_byte (225, subtask); }
	YY_BREAK
case 169:
YY_RULE_SETUP
{ recode_put_byte (233, subtask); }
	YY_BREAK
case 170:
YY_RULE_SETUP
{ recode_put_byte (237, subtask); }
	YY_BREAK
case 171:
YY_RULE_SETUP
{ recode_put_byte (243, subtask); }
	YY_BREAK
case 172:
YY_RULE_SETUP
{ recode_put_byte (250, subtask); }
	YY_BREAK
case 173:
YY_RULE_SETUP
{ recode_put_byte (253, subtask); }
	YY_BREAK
case 174:
YY_RULE_SETUP
{ recode_put_byte (194, subtask); }
	YY_BREAK
case 175:
YY_RULE_SETUP
{ recode_put_byte (202, subtask); }
	YY_BREAK
case 176:
YY_RULE_SETUP
{ recode_put_byte (206, subtask); }
	YY_BREAK
case 177:
YY_RULE_SETUP
{ recode_put_byte (212, subtask); }
	YY_BREAK
case 178:
YY_RULE_SETUP
{ recode_put_byte (219, subtask); }
	YY_BREAK
case 179:
YY_RULE_SETUP
{ recode_put_byte (226, subtask); }
	YY_BREAK
case 180:
YY_RULE_SETUP
{ recode_put_byte (234, subtask); }
	YY_BREAK
case 181:
YY_RULE_SETUP
{ recode_put_byte (238, subtask); }
	YY_BREAK
case 182:
YY_RULE_SETUP
{ recode_put_byte (244, subtask); }
	YY_BREAK
case 183:
YY_RULE_SETUP
{ recode_put_byte (251, subtask); }
	YY_BREAK
case 184:
YY_RULE_SETUP
{ recode_put_byte (195, subtask); }
	YY_BREAK
case 185:
YY_RULE_SETUP
{ recode_put_byte (213, subtask); }
	YY_BREAK
case 186:
YY_RULE_SETUP
{ recode_put_byte (209, subtask); }
	YY_BREAK
case 187:
YY_RULE_SETUP
{ recode_put_byte (227, subtask); }
	YY_BREAK
case 188:
YY_RULE_SETUP
{ recode_put_byte (245, subtask); }
	YY_BREAK
case 189:
YY_RULE_SETUP
{ recode_put_byte (241, subtask); }
	YY_BREAK
case 190:
YY_RULE_SETUP
{ recode_put_byte (175, subtask); }
	YY_BREAK
case 191:
YY_RULE_SETUP
{ recode_put_byte (196, subtask); }
	YY_BREAK
case 192:
YY_RULE_SETUP
{ recode_put_byte (203, subtask); }
	YY_BREAK
case 193:
YY_RULE_SETUP
{ recode_put_byte (207, subtask); }
	YY_BREAK
case 194:
YY_RULE_SETUP
{ recode_put_byte (214, subtask); }
	YY_BREAK
case 195:
YY_RULE_SETUP
{ recode_put_byte (220, subtask); }
	YY_BREAK
case 196:
YY_RULE_SETUP
{ recode_put_byte (228, subtask); }
	YY_BREAK
case 197:
YY_RULE_SETUP
{ recode_put_byte (235, subtask); }
	YY_BREAK
case 198:
YY_RULE_SETUP
{ recode_put_byte (239, subtask); }
	YY_BREAK
case 199:
YY_RULE_SETUP
{ recode_put_byte (246, subtask); }
	YY_BREAK
case 200:
YY_RULE_SETUP
{ recode_put_byte (252, subtask); }
	YY_BREAK
case 201:
YY_RULE_SETUP
{ recode_put_byte (255, subtask); }
	YY_BREAK
case 202:
YY_RULE_SETUP
{ recode_put_byte (197, subtask); }
	YY_BREAK
case 203:
YY_RULE_SETUP
{ recode_put_byte (229, subtask); }
	YY_BREAK
case 204:
YY_RULE_SETUP
{ recode_put_byte (199, subtask); }
	YY_BREAK
case 205:
YY_RULE_SETUP
{ recode_put_byte (231, subtask); }
	YY_BREAK


case 206:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('#', subtask); }
	YY_BREAK
case 207:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('$', subtask); }
	YY_BREAK
case 208:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('%', subtask); }
	YY_BREAK
case 209:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('&', subtask); }
	YY_BREAK
case 210:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('<', subtask); }
	YY_BREAK
case 211:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('>', subtask); }
	YY_BREAK
case 212:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('_', subtask); }
	YY_BREAK
case 213:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('{', subtask); }
	YY_BREAK
case 214:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('}', subtask); }
	YY_BREAK
case 215:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('^', subtask); }
	YY_BREAK
case 216:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('\\', subtask); }
	YY_BREAK
case 217:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (160, subtask); }
	YY_BREAK
case 218:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (161, subtask); }
	YY_BREAK
case 219:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (163, subtask); }
	YY_BREAK
case 220:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (167, subtask); }
	YY_BREAK
case 221:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (168, subtask); }
	YY_BREAK
case 222:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (169, subtask); }
	YY_BREAK
case 223:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (171, subtask); }
	YY_BREAK
case 224:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (172, subtask); }
	YY_BREAK
case 225:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (173, subtask); }
	YY_BREAK
case 226:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (176, subtask); }
	YY_BREAK
case 227:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (177, subtask); }
	YY_BREAK
case 228:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (178, subtask); }
	YY_BREAK
case 229:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (179, subtask); }
	YY_BREAK
case 230:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (180, subtask); }
	YY_BREAK
case 231:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (181, subtask); }
	YY_BREAK
case 232:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (183, subtask); }
	YY_BREAK
case 233:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (184, subtask); }
	YY_BREAK
case 234:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (185, subtask); }
	YY_BREAK
case 235:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (187, subtask); }
	YY_BREAK
case 236:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (188, subtask); }
	YY_BREAK
case 237:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (189, subtask); }
	YY_BREAK
case 238:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (190, subtask); }
	YY_BREAK
case 239:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (191, subtask); }
	YY_BREAK
case 240:
YY_RULE_SETUP
{ recode_put_byte (192, subtask); }
	YY_BREAK
case 241:
YY_RULE_SETUP
{ recode_put_byte (193, subtask); }
	YY_BREAK
case 242:
YY_RULE_SETUP
{ recode_put_byte (194, subtask); }
	YY_BREAK
case 243:
YY_RULE_SETUP
{ recode_put_byte (195, subtask); }
	YY_BREAK
case 244:
YY_RULE_SETUP
{ recode_put_byte (196, subtask); }
	YY_BREAK
case 245:
YY_RULE_SETUP
{ recode_put_byte (197, subtask); }
	YY_BREAK
case 246:
YY_RULE_SETUP
{ recode_put_byte (198, subtask); }
	YY_BREAK
case 247:
YY_RULE_SETUP
{ recode_put_byte (199, subtask); }
	YY_BREAK
case 248:
YY_RULE_SETUP
{ recode_put_byte (200, subtask); }
	YY_BREAK
case 249:
YY_RULE_SETUP
{ recode_put_byte (201, subtask); }
	YY_BREAK
case 250:
YY_RULE_SETUP
{ recode_put_byte (202, subtask); }
	YY_BREAK
case 251:
YY_RULE_SETUP
{ recode_put_byte (203, subtask); }
	YY_BREAK
case 252:
YY_RULE_SETUP
{ recode_put_byte (204, subtask); }
	YY_BREAK
case 253:
YY_RULE_SETUP
{ recode_put_byte (205, subtask); }
	YY_BREAK
case 254:
YY_RULE_SETUP
{ recode_put_byte (206, subtask); }
	YY_BREAK
case 255:
YY_RULE_SETUP
{ recode_put_byte (207, subtask); }
	YY_BREAK
case 256:
YY_RULE_SETUP
{ recode_put_byte (209, subtask); }
	YY_BREAK
case 257:
YY_RULE_SETUP
{ recode_put_byte (210, subtask); }
	YY_BREAK
case 258:
YY_RULE_SETUP
{ recode_put_byte (211, subtask); }
	YY_BREAK
case 259:
YY_RULE_SETUP
{ recode_put_byte (212, subtask); }
	YY_BREAK
case 260:
YY_RULE_SETUP
{ recode_put_byte (213, subtask); }
	YY_BREAK
case 261:
YY_RULE_SETUP
{ recode_put_byte (214, subtask); }
	YY_BREAK
case 262:
YY_RULE_SETUP
{ recode_put_byte (216, subtask); }
	YY_BREAK
case 263:
YY_RULE_SETUP
{ recode_put_byte (217, subtask); }
	YY_BREAK
case 264:
YY_RULE_SETUP
{ recode_put_byte (218, subtask); }
	YY_BREAK
case 265:
YY_RULE_SETUP
{ recode_put_byte (219, subtask); }
	YY_BREAK
case 266:
YY_RULE_SETUP
{ recode_put_byte (220, subtask); }
	YY_BREAK
case 267:
YY_RULE_SETUP
{ recode_put_byte (221, subtask); }
	YY_BREAK
case 268:
YY_RULE_SETUP
{ recode_put_byte (223, subtask); }
	YY_BREAK
case 269:
YY_RULE_SETUP
{ recode_put_byte (224, subtask); }
	YY_BREAK
case 270:
YY_RULE_SETUP
{ recode_put_byte (225, subtask); }
	YY_BREAK
case 271:
YY_RULE_SETUP
{ recode_put_byte (226, subtask); }
	YY_BREAK
case 272:
YY_RULE_SETUP
{ recode_put_byte (227, subtask); }
	YY_BREAK
case 273:
YY_RULE_SETUP
{ recode_put_byte (228, subtask); }
	YY_BREAK
case 274:
YY_RULE_SETUP
{ recode_put_byte (229, subtask); }
	YY_BREAK
case 275:
YY_RULE_SETUP
{ recode_put_byte (230, subtask); }
	YY_BREAK
case 276:
YY_RULE_SETUP
{ recode_put_byte (231, subtask); }
	YY_BREAK
case 277:
YY_RULE_SETUP
{ recode_put_byte (232, subtask); }
	YY_BREAK
case 278:
YY_RULE_SETUP
{ recode_put_byte (233, subtask); }
	YY_BREAK
case 279:
YY_RULE_SETUP
{ recode_put_byte (234, subtask); }
	YY_BREAK
case 280:
YY_RULE_SETUP
{ recode_put_byte (235, subtask); }
	YY_BREAK
case 281:
YY_RULE_SETUP
{ recode_put_byte (236, subtask); }
	YY_BREAK
case 282:
YY_RULE_SETUP
{ recode_put_byte (237, subtask); }
	YY_BREAK
case 283:
YY_RULE_SETUP
{ recode_put_byte (238, subtask); }
	YY_BREAK
case 284:
YY_RULE_SETUP
{ recode_put_byte (239, subtask); }
	YY_BREAK
case 285:
YY_RULE_SETUP
{ recode_put_byte (241, subtask); }
	YY_BREAK
case 286:
YY_RULE_SETUP
{ recode_put_byte (242, subtask); }
	YY_BREAK
case 287:
YY_RULE_SETUP
{ recode_put_byte (243, subtask); }
	YY_BREAK
case 288:
YY_RULE_SETUP
{ recode_put_byte (244, subtask); }
	YY_BREAK
case 289:
YY_RULE_SETUP
{ recode_put_byte (245, subtask); }
	YY_BREAK
case 290:
YY_RULE_SETUP
{ recode_put_byte (246, subtask); }
	YY_BREAK
case 291:
YY_RULE_SETUP
{ recode_put_byte (248, subtask); }
	YY_BREAK
case 292:
YY_RULE_SETUP
{ recode_put_byte (249, subtask); }
	YY_BREAK
case 293:
YY_RULE_SETUP
{ recode_put_byte (250, subtask); }
	YY_BREAK
case 294:
YY_RULE_SETUP
{ recode_put_byte (251, subtask); }
	YY_BREAK
case 295:
YY_RULE_SETUP
{ recode_put_byte (252, subtask); }
	YY_BREAK
case 296:
YY_RULE_SETUP
{ recode_put_byte (253, subtask); }
	YY_BREAK
case 297:
YY_RULE_SETUP
{ recode_put_byte (255, subtask); }
	YY_BREAK
case 298:
YY_RULE_SETUP
{ ECHO; }
	YY_BREAK
case 299:
YY_RULE_SETUP
{ ECHO; }
	YY_BREAK


case 300:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('#', subtask); }
	YY_BREAK
case 301:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('$', subtask); }
	YY_BREAK
case 302:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('%', subtask); }
	YY_BREAK
case 303:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('&', subtask); }
	YY_BREAK
case 304:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('_', subtask); }
	YY_BREAK
case 305:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('{', subtask); }
	YY_BREAK
case 306:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('}', subtask); }
	YY_BREAK
case 307:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE ('\\', subtask); }
	YY_BREAK
case 308:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (160, subtask); }
	YY_BREAK
case 309:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (161, subtask); }
	YY_BREAK
case 310:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (163, subtask); }
	YY_BREAK
case 311:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (167, subtask); }
	YY_BREAK
case 312:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (168, subtask); }
	YY_BREAK
case 313:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (169, subtask); }
	YY_BREAK
case 314:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (171, subtask); }
	YY_BREAK
case 315:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (172, subtask); }
	YY_BREAK
case 316:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (173, subtask); }
	YY_BREAK
case 317:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (176, subtask); }
	YY_BREAK
case 318:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (177, subtask); }
	YY_BREAK
case 319:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (178, subtask); }
	YY_BREAK
case 320:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (179, subtask); }
	YY_BREAK
case 321:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (180, subtask); }
	YY_BREAK
case 322:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (181, subtask); }
	YY_BREAK
case 323:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (183, subtask); }
	YY_BREAK
case 324:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (184, subtask); }
	YY_BREAK
case 325:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (185, subtask); }
	YY_BREAK
case 326:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (187, subtask); }
	YY_BREAK
case 327:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (188, subtask); }
	YY_BREAK
case 328:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (189, subtask); }
	YY_BREAK
case 329:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (190, subtask); }
	YY_BREAK
case 330:
YY_RULE_SETUP
{ PUT_NON_DIACRITIC_BYTE (191, subtask); }
	YY_BREAK
case 331:
YY_RULE_SETUP
{ recode_put_byte (192, subtask); }
	YY_BREAK
case 332:
YY_RULE_SETUP
{ recode_put_byte (193, subtask); }
	YY_BREAK
case 333:
YY_RULE_SETUP
{ recode_put_byte (194, subtask); }
	YY_BREAK
case 334:
YY_RULE_SETUP
{ recode_put_byte (195, subtask); }
	YY_BREAK
case 335:
YY_RULE_SETUP
{ recode_put_byte (196, subtask); }
	YY_BREAK
case 336:
YY_RULE_SETUP
{ recode_put_byte (197, subtask); }
	YY_BREAK
case 337:
YY_RULE_SETUP
{ recode_put_byte (198, subtask); }
	YY_BREAK
case 338:
YY_RULE_SETUP
{ recode_put_byte (199, subtask); }
	YY_BREAK
case 339:
YY_RULE_SETUP
{ recode_put_byte (200, subtask); }
	YY_BREAK
case 340:
YY_RULE_SETUP
{ recode_put_byte (201, subtask); }
	YY_BREAK
case 341:
YY_RULE_SETUP
{ recode_put_byte (202, subtask); }
	YY_BREAK
case 342:
YY_RULE_SETUP
{ recode_put_byte (203, subtask); }
	YY_BREAK
case 343:
YY_RULE_SETUP
{ recode_put_byte (204, subtask); }
	YY_BREAK
case 344:
YY_RULE_SETUP
{ recode_put_byte (205, subtask); }
	YY_BREAK
case 345:
YY_RULE_SETUP
{ recode_put_byte (206, subtask); }
	YY_BREAK
case 346:
YY_RULE_SETUP
{ recode_put_byte (207, subtask); }
	YY_BREAK
case 347:
YY_RULE_SETUP
{ recode_put_byte (209, subtask); }
	YY_BREAK
case 348:
YY_RULE_SETUP
{ recode_put_byte (210, subtask); }
	YY_BREAK
case 349:
YY_RULE_SETUP
{ recode_put_byte (211, subtask); }
	YY_BREAK
case 350:
YY_RULE_SETUP
{ recode_put_byte (212, subtask); }
	YY_BREAK
case 351:
YY_RULE_SETUP
{ recode_put_byte (213, subtask); }
	YY_BREAK
case 352:
YY_RULE_SETUP
{ recode_put_byte (214, subtask); }
	YY_BREAK
case 353:
YY_RULE_SETUP
{ recode_put_byte (216, subtask); }
	YY_BREAK
case 354:
YY_RULE_SETUP
{ recode_put_byte (217, subtask); }
	YY_BREAK
case 355:
YY_RULE_SETUP
{ recode_put_byte (218, subtask); }
	YY_BREAK
case 356:
YY_RULE_SETUP
{ recode_put_byte (219, subtask); }
	YY_BREAK
case 357:
YY_RULE_SETUP
{ recode_put_byte (220, subtask); }
	YY_BREAK
case 358:
YY_RULE_SETUP
{ recode_put_byte (221, subtask); }
	YY_BREAK
case 359:
YY_RULE_SETUP
{ recode_put_byte (223, subtask); }
	YY_BREAK
case 360:
YY_RULE_SETUP
{ recode_put_byte (224, subtask); }
	YY_BREAK
case 361:
YY_RULE_SETUP
{ recode_put_byte (225, subtask); }
	YY_BREAK
case 362:
YY_RULE_SETUP
{ recode_put_byte (226, subtask); }
	YY_BREAK
case 363:
YY_RULE_SETUP
{ recode_put_byte (227, subtask); }
	YY_BREAK
case 364:
YY_RULE_SETUP
{ recode_put_byte (228, subtask); }
	YY_BREAK
case 365:
YY_RULE_SETUP
{ recode_put_byte (229, subtask); }
	YY_BREAK
case 366:
YY_RULE_SETUP
{ recode_put_byte (230, subtask); }
	YY_BREAK
case 367:
YY_RULE_SETUP
{ recode_put_byte (231, subtask); }
	YY_BREAK
case 368:
YY_RULE_SETUP
{ recode_put_byte (232, subtask); }
	YY_BREAK
case 369:
YY_RULE_SETUP
{ recode_put_byte (233, subtask); }
	YY_BREAK
case 370:
YY_RULE_SETUP
{ recode_put_byte (234, subtask); }
	YY_BREAK
case 371:
YY_RULE_SETUP
{ recode_put_byte (235, subtask); }
	YY_BREAK
case 372:
YY_RULE_SETUP
{ recode_put_byte (236, subtask); }
	YY_BREAK
case 373:
YY_RULE_SETUP
{ recode_put_byte (237, subtask); }
	YY_BREAK
case 374:
YY_RULE_SETUP
{ recode_put_byte (238, subtask); }
	YY_BREAK
case 375:
YY_RULE_SETUP
{ recode_put_byte (239, subtask); }
	YY_BREAK
case 376:
YY_RULE_SETUP
{ recode_put_byte (241, subtask); }
	YY_BREAK
case 377:
YY_RULE_SETUP
{ recode_put_byte (242, subtask); }
	YY_BREAK
case 378:
YY_RULE_SETUP
{ recode_put_byte (243, subtask); }
	YY_BREAK
case 379:
YY_RULE_SETUP
{ recode_put_byte (244, subtask); }
	YY_BREAK
case 380:
YY_RULE_SETUP
{ recode_put_byte (245, subtask); }
	YY_BREAK
case 381:
YY_RULE_SETUP
{ recode_put_byte (246, subtask); }
	YY_BREAK
case 382:
YY_RULE_SETUP
{ recode_put_byte (248, subtask); }
	YY_BREAK
case 383:
YY_RULE_SETUP
{ recode_put_byte (249, subtask); }
	YY_BREAK
case 384:
YY_RULE_SETUP
{ recode_put_byte (250, subtask); }
	YY_BREAK
case 385:
YY_RULE_SETUP
{ recode_put_byte (251, subtask); }
	YY_BREAK
case 386:
YY_RULE_SETUP
{ recode_put_byte (252, subtask); }
	YY_BREAK
case 387:
YY_RULE_SETUP
{ recode_put_byte (253, subtask); }
	YY_BREAK
case 388:
YY_RULE_SETUP
{ recode_put_byte (255, subtask); }
	YY_BREAK
case 389:
YY_RULE_SETUP
{ ECHO; }
	YY_BREAK
case 390:
YY_RULE_SETUP
{ ECHO; }
	YY_BREAK


case 391:
YY_RULE_SETUP
{ recode_put_byte (171, subtask); }
	YY_BREAK
case 392:
YY_RULE_SETUP
{ recode_put_byte (187, subtask); }
	YY_BREAK
case 393:
YY_RULE_SETUP
{ recode_put_byte (192, subtask); }
	YY_BREAK
case 394:
YY_RULE_SETUP
{ recode_put_byte (194, subtask); }
	YY_BREAK
case 395:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (196, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 396:
YY_RULE_SETUP
{ recode_put_byte (224, subtask); }
	YY_BREAK
case 397:
YY_RULE_SETUP
{ recode_put_byte (226, subtask); }
	YY_BREAK
case 398:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (228, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 399:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ recode_put_byte (199, subtask); }
	YY_BREAK
case 400:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ recode_put_byte (231, subtask); }
	YY_BREAK
case 401:
YY_RULE_SETUP
{ recode_put_byte (200, subtask); }
	YY_BREAK
case 402:
YY_RULE_SETUP
{ recode_put_byte (201, subtask); recode_put_byte (187, subtask); }
	YY_BREAK
case 403:
YY_RULE_SETUP
{ recode_put_byte ('E', subtask); recode_put_byte (187, subtask); }
	YY_BREAK
case 404:
YY_RULE_SETUP
{ recode_put_byte (201, subtask); }
	YY_BREAK
case 405:
YY_RULE_SETUP
{ recode_put_byte (202, subtask); }
	YY_BREAK
case 406:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (203, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 407:
YY_RULE_SETUP
{ recode_put_byte (232, subtask); }
	YY_BREAK
case 408:
YY_RULE_SETUP
{ recode_put_byte (233, subtask); recode_put_byte (187, subtask); }
	YY_BREAK
case 409:
YY_RULE_SETUP
{ recode_put_byte ('e', subtask); recode_put_byte (187, subtask); }
	YY_BREAK
case 410:
YY_RULE_SETUP
{ recode_put_byte (233, subtask); }
	YY_BREAK
case 411:
YY_RULE_SETUP
{ recode_put_byte (234, subtask); }
	YY_BREAK
case 412:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (235, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 413:
YY_RULE_SETUP
{ recode_put_byte (204, subtask); }
	YY_BREAK
case 414:
YY_RULE_SETUP
{ recode_put_byte (206, subtask); }
	YY_BREAK
case 415:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (207, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 416:
YY_RULE_SETUP
{ recode_put_byte (236, subtask); }
	YY_BREAK
case 417:
YY_RULE_SETUP
{ recode_put_byte (238, subtask); }
	YY_BREAK
case 418:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (239, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 419:
YY_RULE_SETUP
{ recode_put_byte (210, subtask); }
	YY_BREAK
case 420:
YY_RULE_SETUP
{ recode_put_byte (212, subtask); }
	YY_BREAK
case 421:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (214, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 422:
YY_RULE_SETUP
{ recode_put_byte (242, subtask); }
	YY_BREAK
case 423:
YY_RULE_SETUP
{ recode_put_byte (244, subtask); }
	YY_BREAK
case 424:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (246, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 425:
YY_RULE_SETUP
{ recode_put_byte (217, subtask); }
	YY_BREAK
case 426:
YY_RULE_SETUP
{ recode_put_byte (219, subtask); }
	YY_BREAK
case 427:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (220, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 428:
YY_RULE_SETUP
{ recode_put_byte (249, subtask); }
	YY_BREAK
case 429:
YY_RULE_SETUP
{ recode_put_byte (251, subtask); }
	YY_BREAK
case 430:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ if (yytext[1] == request->diaeresis_char)
			    recode_put_byte (252, subtask);
			  else
			    ECHO;
			}
	YY_BREAK
case 431:
/* rule 431 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 432:
/* rule 432 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 433:
/* rule 433 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 434:
/* rule 434 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 435:
/* rule 435 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 436:
/* rule 436 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 437:
/* rule 437 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 438:
/* rule 438 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 439:
/* rule 439 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 440:
/* rule 440 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 441:
/* rule 441 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 442:
/* rule 442 can match eol */
YY_RULE_SETUP
{ if (yytext[4] == request->diaeresis_char)
			    texte_latin1_diaeresis ();
			  else
			    ECHO;
			}
	YY_BREAK
case 443:
/* rule 443 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 444:
YY_RULE_SETUP
{ ECHO; }
	YY_BREAK
case 445:
/* rule 445 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 446:
/* rule 446 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 447:
/* rule 447 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 448:
/* rule 448 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 449:
/* rule 449 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK
case 450:
/* rule 450 can match eol */
YY_RULE_SETUP
{ texte_latin1_diaeresis (); }
	YY_BREAK

case 451:
YY_RULE_SETUP
ECHO;
	YY_BREAK

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1261 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1261 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1260);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"


/* Conversion of files between different charsets and surfaces.
   Copyright © 1990-2000 Free Software Foundation, Inc.
   This file is part of the GNU C Library.
   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License
   as published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   This library is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty
   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Recode Library; see the file `COPYING.LIB'.
   If not, see <https://www.gnu.org/licenses/>.
*/


static bool
transform_ascii_latin1 (RECODE_SUBTASK subtask_argument)
{
  subtask = subtask_argument;
  request = subtask->task->request;
  yy_init = 0;
  yyin = subtask->input.file;
  yyout = subtask->output.file;
  BEGIN ascii_latin1;
  return yylex ();
}

bool
module_ascii_latin1 (RECODE_OUTER outer)
{
  if (!recode_declare_single (outer, "ASCII-BS", "Latin-1",
		       outer->quality_variable_to_byte,
		       NULL, transform_ascii_latin1))
    return false;

  return true;
}

void
delmodule_ascii_latin1 (RECODE_OUTER outer)
{
}
/*
 * Copyright (c) 1998, Wolfram Schneider <wosch@freebsd.org>
 *                     Konrad Zuse Zentrum für Informationstechnik Berlin.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *
 * iso5426 to iso8859-1 conversion. This file support only a subset
 * of ISO 5426:1983. It is incomplete due the lack of free
 * available documentation ;-(
 * 
 * The character conversion based on the german MAB2 (Maschinelles 
 * Austauschformat für Bibliotheken) documentation, October 1996, 
 * die Deutsche Bibliothek, Frankfurt am Main. 
 * URL: http://www.ddb.de, ftp://ftp.ddb.de/pub/mab/
 *
 *
 * http://lcweb.loc.gov/loc/standards/isotc46/sc4standards.html
 * Character sets: 
 * ISO 5426:1983 -   Extension of the Latin alphabet coded character
 *                   set for bibliographic information interchange 
 * ISO 5426-2:1996 - Extension of the Latin alphabet coded character set 
 *                   for bibliographic information interchange 
 *                   Part 2: Latin characters used in minor European 
 *                   languages and obsolete typography 
 *
 * 
 * ISO 5426:1983
 * 
 * Extension of the Latin alphabet coded character set for bibliographic
 * information interchange
 * 
 * Contains a set of 76 graphic characters with their coded
 * representations. It includes a code table and a legend showing each
 * graphic, its name and use, and explanatory notes. Primarily intended
 * for information interchange among data processing systems and within
 * message transmission systems, this character set is designed to handle
 * information in 39 specified languages, as well as transliterated or
 * romanized forms of an additional 32 languages. These characters,
 * together with the characters in the international reference version of
 * ISO 646 (ISO escape sequence ESC 2/8 4/0), constitute a character set
 * for the international interchange of bibliographic citations,
 * including their annotations, in the Latin alphabet.
 * 
 * ISO 5426-2:1996 
 * 
 * Extension of the Latin alphabet coded character set for bibliographic
 * information interchange Part 2: Latin characters used in minor
 * European languages and obsolete typography
 * 
 * Contains a set of 70 graphic characters, and their coded
 * representations. These characters form a supplement to those provided
 * in ISO 5426 by addressing less common and obsolete languages which use
 * the Latin script and obsolete printing conventions. Included is a code
 * table and a legend showing each graphic, its name and use, and
 * explanatory notes. This character set is primarily intended for
 * information interchange among data processing systems and within
 * message transmission systems. These characters, together with the
 * characters from ISO 646/IEC and ISO 5426, is intended to handle
 * information in the following languages: Anglo-Saxon, Greenlandic,
 * Lappish, Latin, Latvian (older forms), and Maltese. It is also
 * intended to cover printing conventions associated with older books, in
 * particular marks associated with binding signatures.
 * 
 */



static bool
transform_iso5426_latin1 (RECODE_SUBTASK subtask_argument)
{
  subtask = subtask_argument;
  request = subtask->task->request;
  yy_init = 0;
  yyin = subtask->input.file;
  yyout = subtask->output.file;
  BEGIN iso5426_latin1;
  return yylex ();
}

bool
module_iso5426_latin1 (RECODE_OUTER outer)
{
  return recode_declare_single (outer, "ISO_5426:1983-DB-MAB2", "Latin-1", 
                         outer->quality_variable_to_byte, NULL,
                         transform_iso5426_latin1)
    && recode_declare_alias (outer, "ISO_5426", "ISO_5426:1983-DB-MAB2")
    && recode_declare_alias (outer, "DB-MAB2", "ISO_5426:1983-DB-MAB2")
    && recode_declare_alias (outer, "MAB2", "ISO_5426:1983-DB-MAB2")
    && recode_declare_alias (outer, "MAB", "ISO_5426:1983-DB-MAB2")
    && recode_declare_alias (outer, "DDB", "ISO_5426:1983-DB-MAB2"); /* Die Deutsche Bibliothek */
}

void
delmodule_iso5426_latin1 (RECODE_OUTER outer)
{
}
/*
 * Copyright (c) 1998, Wolfram Schneider <wosch@freebsd.org>
 *                     Konrad Zuse Zentrum für Informationstechnik Berlin.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *
 * 8-Bit ANSEL to ISO8859-1 conversion. This file support only a subset
 * of Z39.47-1993 (ANSEL). It is incomplete due the lack of free
 * available documentation ;-(
 *
 * http://www.niso.org/pccodes.htm
 * Z39.47-1993 Extended Latin Alphabet Coded Character Set for
 * Bibliographic Use (ANSEL)
 * 
 * Character sets are a basic building block of automated information
 * systems. Z39.47 provides a table of coded values for the
 * representation of characters of the extended Latin alphabet in
 * machine-readable form for thirty-five languages written in the Latin
 * alphabet and for fifty-one romanized languages.
 * 
 * 27 pp. ISBN: 1-880124-02-5 Price: $40.00 
 * 
 *
 * http://wwnet.com/~krugman1/gentext/gedstand.txt
 * 8-Bit ANSEL
 * 
 * The 8-Bit ANSEL (American National Standard for Extended Latin
 * Alphabet Coded Character Set for Bibliographic Use, Z39.47, 1985
 * copyright) is the default character set for GEDCOM. [...]
 * The ANSEL standard
 * specifies an extended 8-bit configuration (above 128) to represent the
 * spacing and non-spacing graphic characters that make up most of the
 * Latin based languages.  ANSEL is a super-set of ASCII.  The standard
 * ASCII characters including the control characters are preserved.
 * 
 * ANSEL is known by two other names: (1) ANSI Z39.47-1985) and (2) the
 * American Library Association character set, used in library systems
 * worldwide, including the MARC (MAchine- Readable Catalog) format.
 * 
 * A description of the codes for the ANSEL character set has been
 * reproduced with permission and is included with the printed version of
 * The GEDCOM Standard. The description of ANSEL codes is not included in
 * the electronic version.  This description may be purchased from the
 * American National Standards Institute at 1430 Broadway, New York,
 * N.Y. 10018.  The description of the ANSEL character set standard
 * includes the following:
 * 
 *     *       An 8-Bit Code Table showing the ASCII and extended ANSEL codes
 *     *       An explanation or legend of these codes
 *     *       A chart that identifies the ANSEL Non-spacing Graphic Characters
 *     *       A chart that identifies the ASCII Control Characters
 *     *       A chart that identifies the ASCII Graphic Characters
 * 
 * Character-set codes 0 through 127 are the same for 8-Bit ANSEL and
 * 8-Bit ASCII (USA version-- ANSI 8-Bit). Character-set codes 128
 * through 255 are unique to the ANSEL character set.
 * 
 * Changes
 * ========
 * Fix ansel characters 
 * 
 * 	Capital C with cedilla
 * 	Lower case C with cedilla
 * 	Capital ETH 
 * 	Lower case eth
 * 	Capital O with slash
 * 	Capital Y with acute accent
 * 	Lower case Icelandic thorn     
 * 	capital OE ligature
 * 
 * Thanks to Larry E. Dixson <ldix@loc.gov>
 * 
 */



static bool
transform_ansel_latin1 (RECODE_SUBTASK subtask_argument)
{
  subtask = subtask_argument;
  request = subtask->task->request;
  yy_init = 0;
  yyin = subtask->input.file;
  yyout = subtask->output.file;
  BEGIN ansel_latin1;
  return yylex ();
}

bool
module_ansel_latin1 (RECODE_OUTER outer)
{
  return recode_declare_single (outer, "Z39.47:1993", "Latin-1",
                         outer->quality_variable_to_byte, NULL,
                         transform_ansel_latin1)
    && recode_declare_alias (outer, "8bitANSEL", "Z39.47:1993")
    && recode_declare_alias (outer, "Z39.47", "Z39.47:1993")
    && recode_declare_alias (outer, "ANSEL", "Z39.47:1993")
    && recode_declare_alias (outer, "USMARC", "Z39.47:1993")
    && recode_declare_alias (outer, "MARC", "Z39.47:1993")
    && recode_declare_alias (outer, "LOC", "Z39.47:1993"); /* Library of Congress */
}

void
delmodule_ansel_latin1 (RECODE_OUTER outer)
{
}
/* Conversion of files between different charsets and surfaces.
   Copyright © 1990-2018 Free Software Foundation, Inc.
   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License
   as published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   This library is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty
   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Recode Library; see the file `COPYING.LIB'.
   If not, see <https://www.gnu.org/licenses/>.
*/


static bool
transform_latex_latin1 (RECODE_SUBTASK subtask_argument)
{
  subtask = subtask_argument;
  request = subtask->task->request;
  yy_init = 0;
  yyin = subtask->input.file;
  yyout = subtask->output.file;
  BEGIN latex_latin1;
  return yylex ();
}

bool
module_latex_latin1 (RECODE_OUTER outer)
{
  return
    recode_declare_single (outer, "LaTeX", "Latin-1",
                    outer->quality_variable_to_byte,
                    NULL, transform_latex_latin1)
    && recode_declare_alias (outer, "TeX", "LaTeX")
    && recode_declare_alias (outer, "ltex", "LaTeX");
}

void
delmodule_latex_latin1 (RECODE_OUTER outer)
{
}
/* Conversion of files between different charsets and surfaces.
   Copyright © 1990-2018 Free Software Foundation, Inc.
   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License
   as published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   This library is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty
   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the `recode' Library; see the file `COPYING.LIB'.
   If not, see <https://www.gnu.org/licenses/>.
*/


static bool
transform_bibtex_latin1 (RECODE_SUBTASK subtask_argument)
{
  subtask = subtask_argument;
  request = subtask->task->request;
  yy_init = 0;
  yyin = subtask->input.file;
  yyout = subtask->output.file;
  BEGIN bibtex_latin1;
  return yylex ();
}

bool
module_bibtex_latin1 (RECODE_OUTER outer)
{
  return
    recode_declare_single (outer, "BibTeX", "Latin-1",
                    outer->quality_variable_to_byte,
                    NULL, transform_bibtex_latin1)
    && recode_declare_alias (outer, "btex", "BibTeX");
}

void
delmodule_bibtex_latin1 (RECODE_OUTER outer)
{
}
/* Conversion of files between different charsets and surfaces.
   Copyright © 1990-2000 Free Software Foundation, Inc.
   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1989.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License
   as published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   This library is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty
   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Recode Library; see the file `COPYING.LIB'.
   If not, see <https://www.gnu.org/licenses/>.
*/


static bool
transform_texte_latin1 (RECODE_SUBTASK subtask_argument)
{
  subtask = subtask_argument;
  request = subtask->task->request;
  yy_init = 0;
  yyin = subtask->input.file;
  yyout = subtask->output.file;
  BEGIN texte_latin1;
  return yylex ();
}

void
texte_latin1_diaeresis (void)
{
  unsigned counter;

  for (counter = 0; counter < yyleng; counter++)
    if (yytext[counter+1] == request->diaeresis_char)
      {
	switch (yytext[counter])
	  {
	    /* The next "case 'A'" line once triggered a `NULL in input'
	       diagnostic in flex.  This astonishing bug has been hard to
	       isolate, so I'll leave this comment around for a while.  */

	  case 'A': recode_put_byte (196, subtask); break;
	  case 'E': recode_put_byte (203, subtask); break;
	  case 'I': recode_put_byte (207, subtask); break;
	  case 'O': recode_put_byte (214, subtask); break;
	  case 'U': recode_put_byte (220, subtask); break;
	  case 'a': recode_put_byte (228, subtask); break;
	  case 'e': recode_put_byte (235, subtask); break;
	  case 'i': recode_put_byte (239, subtask); break;
	  case 'o': recode_put_byte (246, subtask); break;
	  case 'u': recode_put_byte (252, subtask); break;
	  case 'y': recode_put_byte (255, subtask); break;
	  default:  recode_put_byte (yytext[counter], subtask);
	  }
	counter++;
      }
    else
      recode_put_byte (yytext[counter], subtask);
}

bool
module_texte_latin1 (RECODE_OUTER outer)
{
  return
    recode_declare_single (outer, "Texte", "Latin-1",
		    outer->quality_variable_to_byte, NULL,
		    transform_texte_latin1)
    && recode_declare_alias (outer, "txte", "Texte");
}

void
delmodule_texte_latin1 (RECODE_OUTER outer)
{
}

